@@ -44,6 +44,9 @@
 
 #include <stdio.h> 
 #include <ClanLib/lua.h>
+#include <ClanLib/display.h>
+#include <ClanLib/sound.h>
+#include <ClanLib/network.h>
 #include <ClanLib/mikmod.h>
 
 /*---------------------------------------------------------------------------
@@ -66,7 +69,7 @@ char *U61_Application::get_title()
     
   U61_Version::get_version_text(buf);
   sprintf(app_name,
-	  "U61 %s by U-Foot (ufoot@ufoot.org / www.ufoot.org)",
+	  "U61 %s",
 	  buf);
 
   return app_name; 
@@ -80,49 +83,117 @@ int U61_Application::main(int argc, char **argv)
 {
   int retcode=0;
   char buf[U61_CONST_STRING_SIZE];
-  
-  CL_SetupCore::init();
-  CL_SetupCore::init_display();
-  CL_SetupCore::init_sound();
-  CL_SetupCore::init_network();
-  CL_SetupMikMod::init();
-  CL_Lua::open();
 
-  U61_Debug::init();
-  U61_Version::get_version_text(buf);
-  U61_LOG_MESSAGE("Starting "<<buf<<"...");
-
-  try
+  if (process_options(argc,argv))
     {
-     if (U61_Global::game.init(argv[0]))
-        {
-	  U61_LOG_MESSAGE("Init OK!");
-          U61_Global::game.run();
-        }
-      else
+      CL_SetupCore::init();
+      CL_SetupDisplay::init();
+      CL_SetupSound::init();
+      CL_SetupNetwork::init();
+      CL_SetupMikMod::init();
+      CL_Lua::open();
+
+      U61_Debug::init();
+      U61_Version::get_version_text(buf);
+      U61_LOG_MESSAGE("Starting "<<buf<<"...");
+
+      try
 	{
-	  U61_LOG_WARNING("Init failed 8-(");
-	  U61_LOG_WARNING("Many init problems come from a bad configuration file, so please check or remove the \""<<U61_Platform::get_config_file()<<"\" file, and try and restart the game. If this does not help, report bugs to ufoot@ufoot.org. Good luck.");
+	  if (U61_Global::game.init(argv[0]))
+	    {
+	      U61_LOG_MESSAGE("Init OK!");
+	      U61_Global::game.run();
+	    }
+	  else
+	    {
+	      U61_LOG_WARNING("Init failed 8-(");
+	      U61_LOG_WARNING("Many init problems come from a bad configuration file, so please check or remove the \""<<U61_Platform::get_config_file()<<"\" file, and try and restart the game. If this does not help, report bugs to ufoot@ufoot.org. Good luck.");
+	    }
+	  U61_Global::game.deinit();
+	}
+      catch (CL_Error e)
+	{
+	  U61_LOG_ERROR("Unhandled error: "<<e.message.c_str());
+	  U61_LOG_ERROR("Please report bugs to ufoot@ufoot.org.");
+	  retcode=1;
 	}
-      U61_Global::game.deinit();
-    }
-  catch (CL_Error e)
-    {
-      U61_LOG_ERROR("Unhandled error: "<<e.message.c_str());
-      U61_LOG_ERROR("Please report bugs to ufoot@ufoot.org.");
-      retcode=1;
-    }
 
-  U61_LOG_MESSAGE("Game over...");
-  U61_Debug::deinit();
+      U61_LOG_MESSAGE("Game over...");
+      U61_Debug::deinit();
 
-  CL_Lua::close();
-  CL_SetupMikMod::deinit();
-  CL_SetupCore::deinit_network();    
-  CL_SetupCore::deinit_sound();
-  CL_SetupCore::deinit_display();
-  CL_SetupCore::deinit();
+      CL_Lua::close();
+      CL_SetupMikMod::deinit();
+      CL_SetupNetwork::deinit();    
+      CL_SetupSound::deinit();
+      CL_SetupDisplay::deinit();
+      CL_SetupCore::deinit();
+    }
 
   return retcode;
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * Processes the command line parameters
+ */ 
+bool U61_Application::process_options(int argc,char **argv)
+{
+  char buf[U61_CONST_STRING_SIZE];        
+  char c;
+  bool result=true;
+  int i;
+
+  for (i=1;i<argc;++i)
+    {
+      if (argv[i][0]=='-' || argv[i][0]=='/')
+	{
+	  c=argv[i][1];
+	  switch (c)
+	    {
+	    case 'v':
+	      U61_Version::get_version_text(buf);
+	      cout<<buf<<"\n";
+	      result=false;
+	      break;
+	    case '?':
+	    case 'h':
+	      U61_Version::get_version_text(buf);
+	      cout<<"\n";
+	      cout<<"U61 - another block-based game\n";
+	      cout<<"\n";
+	      cout<<"v"<<buf<<" compiled on "<<__DATE__<<" at "__TIME__"\n";
+	      cout<<"Copyright (C) 2000-2001 Christian Mauduit\n";
+	      cout<<"\n";
+	      cout<<"This program is free software; you can redistribute it and/or modify\n";
+	      cout<<"it under the terms of the GNU General Public License as published by\n";
+	      cout<<"the Free Software Foundation; either version 2 of the License, or\n";
+	      cout<<"(at your option) any later version.\n";
+	      cout<<"\n";
+
+	      cout<<"This program is distributed in the hope that it will be useful,\n";
+	      cout<<"but WITHOUT ANY WARRANTY; without even the implied warranty of\n";
+	      cout<<"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n";
+	      cout<<"GNU General Public License for more details.\n";
+
+	      cout<<"\n";
+	      cout<<"You should have received a copy of the GNU General Public License\n";
+	      cout<<"along with this program; if not, write to the Free Software\n";
+	      cout<<"Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA\n";
+	      cout<<"\n";
+	      cout<<"Documentation is available in HTML, ascii text, PostScript, PDF... Read it 8-)\n";
+	      cout<<"\n";
+	      cout<<"U61 homepage   : http://www.ufoot.org/u61\n";
+	      cout<<"Contact author : ufoot@ufoot.org\n";
+	      result=false;
+	      break;
+	    default:
+	      cout<<"Unknown option '"<<c<<"' \n";
+	      result=false;
+	      break;
+	    }
+	}
+    }
+
+  return result;
+}
+
