@@ -60,7 +60,7 @@
  */ 
 U61_Block::U61_Block()
 {
-    reset();
+  reset();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -74,19 +74,29 @@ U61_Block::~U61_Block()
 
 /*--------------------------------------------------------------------------*/
 /*
- * empties a block from its squares 
+ * empties a block from its squares, and places it at position (0,0) 
  */
 void U61_Block::reset()
 {
-    int i;
+  clear();
 
-    for (i=0;i<U61_BLOCK_MAX_ITEMS;++i)
+  pos_x=0;
+  pos_y=0;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * empties a block from its squares 
+ */
+void U61_Block::clear()
+{
+  int i;
+
+  for (i=0;i<U61_BLOCK_MAX_ITEMS;++i)
     {
-        items[i].reset();
+      items[i].reset();
     }
-    nb_items=0;
-    pos_x=0;
-    pos_y=0;
+  nb_items=0;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -95,7 +105,7 @@ void U61_Block::reset()
  */
 int U61_Block::get_x()
 {
-    return pos_x;
+  return pos_x;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -104,7 +114,7 @@ int U61_Block::get_x()
  */
 int U61_Block::get_y()
 {
-    return pos_y;
+  return pos_y;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -113,7 +123,7 @@ int U61_Block::get_y()
  */
 void U61_Block::set_x(int x)
 {
-    pos_x=x;
+  pos_x=x;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -122,7 +132,7 @@ void U61_Block::set_x(int x)
  */
 void U61_Block::set_y(int y)
 {
-    pos_y=y;
+  pos_y=y;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -132,15 +142,15 @@ void U61_Block::set_y(int y)
  */
 void U61_Block::add_item(int x,int y,int color)
 {
-    U61_Square sq;
+  U61_Square sq;
 
-    if (nb_items<U61_BLOCK_MAX_ITEMS)
+  if (nb_items<U61_BLOCK_MAX_ITEMS)
     {
-        items[nb_items].square.enable();
-        items[nb_items].square.set_color(color);
-        items[nb_items].set_x(x);
-        items[nb_items].set_y(y);
-        nb_items++;
+      items[nb_items].square.enable();
+      items[nb_items].square.set_color(color);
+      items[nb_items].set_x(x);
+      items[nb_items].set_y(y);
+      nb_items++;
     }
 }
 
@@ -150,7 +160,7 @@ void U61_Block::add_item(int x,int y,int color)
  */
 int U61_Block::get_nb_items()
 {
-    return nb_items;    
+  return nb_items;    
 }
 
 /*--------------------------------------------------------------------------*/
@@ -160,7 +170,7 @@ int U61_Block::get_nb_items()
  */
 int U61_Block::get_item_x(int i)
 {
-    return (i>=0 && i<nb_items) ? items[i].get_x() : 0;
+  return (i>=0 && i<nb_items) ? items[i].get_x() : 0;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -170,7 +180,7 @@ int U61_Block::get_item_x(int i)
  */
 int U61_Block::get_item_y(int i)
 {
-    return (i>=0 && i<nb_items) ? items[i].get_y() : 0;
+  return (i>=0 && i<nb_items) ? items[i].get_y() : 0;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -180,7 +190,7 @@ int U61_Block::get_item_y(int i)
  */
 int U61_Block::get_item_color(int i)
 {
-    return (i>=0 && i<nb_items) ? items[i].square.get_color() : 0;
+  return (i>=0 && i<nb_items) ? items[i].square.get_color() : 0;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -190,9 +200,9 @@ int U61_Block::get_item_color(int i)
  */
 void U61_Block::set_item_x(int i,int x)
 {
-    if (i>=0 && i<nb_items)
+  if (i>=0 && i<nb_items)
     {
-        items[i].set_x(x);
+      items[i].set_x(x);
     }
 }
 
@@ -203,9 +213,9 @@ void U61_Block::set_item_x(int i,int x)
  */
 void U61_Block::set_item_y(int i,int y)
 {
-    if (i>=0 && i<nb_items)
+  if (i>=0 && i<nb_items)
     {
-        items[i].set_y(y);
+      items[i].set_y(y);
     }
 }
 
@@ -216,9 +226,9 @@ void U61_Block::set_item_y(int i,int y)
  */
 void U61_Block::set_item_color(int i,int color)
 {
-    if (i>=0 && i<nb_items)
+  if (i>=0 && i<nb_items)
     {
-        items[i].square.set_color(color);
+      items[i].square.set_color(color);
     }
 }
 
@@ -235,7 +245,7 @@ void U61_Block::set_item_color(int i,int color)
  */
 U61_BlockItem *U61_Block::get_item(int i)
 {
-    return items+i;
+  return items+i;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -247,50 +257,50 @@ U61_BlockItem *U61_Block::get_item(int i)
  */
 void U61_Block::center()
 {
-    int i;
-    int x_max;
-    int y_max;
-    int x_min;
-    int y_min;
-    int x_offset;
-    int y_offset;
+  int i;
+  int x_max;
+  int y_max;
+  int x_min;
+  int y_min;
+  int x_offset;
+  int y_offset;
  
-    /*
-     * if there are no squares, there's nothing to do...
-     */
-    if (nb_items>0)
+  /*
+   * if there are no squares, there's nothing to do...
+   */
+  if (nb_items>0)
     {
-        /*
-         * initialization of min & max values
-         */
-        x_max=x_min=items[0].get_x();
-        y_max=y_min=items[0].get_y();
+      /*
+       * initialization of min & max values
+       */
+      x_max=x_min=items[0].get_x();
+      y_max=y_min=items[0].get_y();
 
-        /*
-         * we seek for greater or lower values
-         */
-        for (i=1;i<nb_items;++i)
+      /*
+       * we seek for greater or lower values
+       */
+      for (i=1;i<nb_items;++i)
         {
-			 x_max=max(x_max,items[i].get_x());    
-             x_min=min(x_min,items[i].get_x());    
-             y_max=max(y_max,items[i].get_y());    
-             y_min=min(y_min,items[i].get_y());    
+	  x_max=max(x_max,items[i].get_x());    
+	  x_min=min(x_min,items[i].get_x());    
+	  y_max=max(y_max,items[i].get_y());    
+	  y_min=min(y_min,items[i].get_y());    
         }
 
-        /*
-         * we calculate the offsets
-         */
-        x_offset=(x_max+x_min+1)/2;
-        y_offset=(y_max+y_min+1)/2;
+      /*
+       * we calculate the offsets
+       */
+      x_offset=(x_max+x_min+1)/2;
+      y_offset=(y_max+y_min+1)/2;
         
-        /*
-         * we substract the offset from all the coordinates,
-         * so that the block is centedred
-         */
-        for (i=0;i<nb_items;++i)
+      /*
+       * we substract the offset from all the coordinates,
+       * so that the block is centedred
+       */
+      for (i=0;i<nb_items;++i)
         {
-            items[i].set_x(items[i].get_x()-x_offset);
-            items[i].set_y(items[i].get_y()-y_offset);
+	  items[i].set_x(items[i].get_x()-x_offset);
+	  items[i].set_y(items[i].get_y()-y_offset);
         } 
     }
 }
@@ -302,25 +312,25 @@ void U61_Block::center()
  */
 void U61_Block::corner()
 {
-    int i;
-    int x_min;
-    int y_min;
+  int i;
+  int x_min;
+  int y_min;
 
-    if (nb_items>0)
+  if (nb_items>0)
     {
-        x_min=items[0].get_x();
-        y_min=items[0].get_y();
+      x_min=items[0].get_x();
+      y_min=items[0].get_y();
 
-        for (i=1;i<nb_items;++i)
+      for (i=1;i<nb_items;++i)
         {
-            x_min=min(x_min,items[i].get_x());
-            y_min=min(y_min,items[i].get_y());
+	  x_min=min(x_min,items[i].get_x());
+	  y_min=min(y_min,items[i].get_y());
         }
         
-        for (i=0;i<nb_items;++i)
+      for (i=0;i<nb_items;++i)
         {
-            items[i].set_x(items[i].get_x()-x_min);
-            items[i].set_y(items[i].get_y()-y_min);
+	  items[i].set_x(items[i].get_x()-x_min);
+	  items[i].set_y(items[i].get_y()-y_min);
         }
     }
 }
@@ -331,18 +341,18 @@ void U61_Block::corner()
  */
 void U61_Block::draw(int x,int y,int size)
 {
-    int i;
-    int x2,y2;
+  int i;
+  int x2,y2;
 
-    for (i=0;i<nb_items;++i)
+  for (i=0;i<nb_items;++i)
     {
-        x2=pos_x+items[i].get_x();
-        y2=pos_y+items[i].get_y();
-        if (x2>=0 && y2>=0 && x2<U61_MAP_WIDTH && y2<U61_MAP_HEIGHT)
+      x2=pos_x+items[i].get_x();
+      y2=pos_y+items[i].get_y();
+      if (x2>=0 && y2>=0 && x2<U61_MAP_WIDTH && y2<U61_MAP_HEIGHT)
         {
-            x2=x+x2*U61_Global::data.square_w[size];
-            y2=y+y2*U61_Global::data.square_h[size];
-            items[i].square.draw(x2,y2,size);
+	  x2=x+x2*U61_Global::data.square_w[size];
+	  y2=y+y2*U61_Global::data.square_h[size];
+	  items[i].square.draw(x2,y2,size);
         }
     }
 }
@@ -353,18 +363,18 @@ void U61_Block::draw(int x,int y,int size)
  */
 void U61_Block::draw_anticipation(int x,int y,int size)
 {
-    int i;
-    int x2,y2;
+  int i;
+  int x2,y2;
 
-    for (i=0;i<nb_items;++i)
+  for (i=0;i<nb_items;++i)
     {
-        x2=pos_x+items[i].get_x();
-        y2=pos_y+items[i].get_y();
-        if (x2>=0 && y2>=0 && x2<U61_MAP_WIDTH && y2<U61_MAP_HEIGHT)
+      x2=pos_x+items[i].get_x();
+      y2=pos_y+items[i].get_y();
+      if (x2>=0 && y2>=0 && x2<U61_MAP_WIDTH && y2<U61_MAP_HEIGHT)
         {
-            x2=x+x2*U61_Global::data.square_w[size];
-            y2=y+y2*U61_Global::data.square_h[size];
-            items[i].square.draw_anticipation(x2,y2,size);
+	  x2=x+x2*U61_Global::data.square_w[size];
+	  y2=y+y2*U61_Global::data.square_h[size];
+	  items[i].square.draw_anticipation(x2,y2,size);
         }
     }
 }
@@ -375,24 +385,24 @@ void U61_Block::draw_anticipation(int x,int y,int size)
  */
 void U61_Block::draw_preview(int x,int y,int size)
 {
-    int i;
-    int x2,y2;
+  int i;
+  int x2,y2;
 
-    x+=(U61_BLOCK_PREVIEW_WIDTH/2)*U61_Global::data.square_w[size];
-    y+=(U61_BLOCK_PREVIEW_HEIGHT/2)*U61_Global::data.square_h[size];
+  x+=(U61_BLOCK_PREVIEW_WIDTH/2)*U61_Global::data.square_w[size];
+  y+=(U61_BLOCK_PREVIEW_HEIGHT/2)*U61_Global::data.square_h[size];
 
-    for (i=0;i<nb_items;++i)
+  for (i=0;i<nb_items;++i)
     {
-        x2=items[i].get_x();
-        y2=items[i].get_y();
-        if (x2>=-U61_BLOCK_PREVIEW_WIDTH/2 
-	    && y2>=-U61_BLOCK_PREVIEW_HEIGHT/2
-            && x2<U61_BLOCK_PREVIEW_WIDTH/2 
-	    && y2<U61_BLOCK_PREVIEW_HEIGHT/2)
+      x2=items[i].get_x();
+      y2=items[i].get_y();
+      if (x2>=-U61_BLOCK_PREVIEW_WIDTH/2 
+	  && y2>=-U61_BLOCK_PREVIEW_HEIGHT/2
+	  && x2<U61_BLOCK_PREVIEW_WIDTH/2 
+	  && y2<U61_BLOCK_PREVIEW_HEIGHT/2)
         {	  
-            x2=x+x2*U61_Global::data.square_w[size];
-            y2=y+y2*U61_Global::data.square_h[size];
-            items[i].square.draw(x2,y2,size);
+	  x2=x+x2*U61_Global::data.square_w[size];
+	  y2=y+y2*U61_Global::data.square_h[size];
+	  items[i].square.draw(x2,y2,size);
         }
     }
 }
