@@ -48,6 +48,12 @@
 #include "clientdispatcher.h"
 #include "const.h"
 
+/*---------------------------------------------------------------------------
+ constants
+ ---------------------------------------------------------------------------*/
+
+#define U61_CLIENTPROTOCOL_JOIN_DELAY              100
+
 /*---------------------------------------------------------------------------
  classes
  ---------------------------------------------------------------------------*/
@@ -63,7 +69,6 @@ class U61_ClientProtocol : public U61_Protocol
   virtual int recv_next_packet();
 
  protected:
-  static const unsigned int JOIN_DELAY=100;
   
   char *server_id;
   U61_ClientDispatcher *dispatcher;
@@ -77,21 +82,6 @@ class U61_ClientProtocol : public U61_Protocol
   unsigned int join_delay_start;
   int channel_to_test;
 
-  const static int SEARCHING=10;
-  const static int CONNECTED_TO_SERVER=11;
-  const static int JOIN_DELAY_ELAPSED=12;
-  const static int CHANNEL_FOUND=13;
-  const static int SCRIPT_NAME_RECEIVED=30;
-  const static int SCRIPT_RECEIVED=31;
-  const static int ID0_RECEIVED=40;
-  const static int ID1_RECEIVED=41;
-  const static int INITIAL_SPEED_RECEIVED=42;
-  const static int ACCELERATION_RECEIVED=43;
-  const static int CURSE_DELAY_RECEIVED=44;
-  const static int TIME_RECEIVED=45;
-  const static int PLAYING=60;    
-  const static int CLOSED=61;
-
   int start_searching();
   int connect_to_server();
   int join_delay();
