@@ -50,6 +50,7 @@
 #include "debug.h"
 #include "sound.h"
 #include "music.h"
+#include "global.h"
 
 #include <ClanLib/lua.h>
 
@@ -137,6 +138,8 @@ bool U61_Config::read()
 {
   bool ok=false;
   char *filename;
+  
+  U61_Global::data.chdir_to_initial_dir();
 
   U61_LOG_DEBUG("read config");
   filename=U61_Platform::get_config_file();
@@ -150,7 +153,9 @@ bool U61_Config::read()
     }
 
   reset();
- 
+  
+  U61_Global::data.chdir_to_data_dir();
+
   return ok;
 }
    
@@ -277,6 +282,8 @@ bool U61_Config::write()
   char *filename;
   FILE *file;
   int pl;
+  
+  U61_Global::data.chdir_to_initial_dir();
 
   U61_LOG_DEBUG("write config");
   if (U61_Platform::create_user_dir())
@@ -362,6 +369,9 @@ bool U61_Config::write()
 	  fclose(file);
 	}
     }
+  
+  U61_Global::data.chdir_to_data_dir();
+
   return ok;
 }
 
@@ -425,22 +435,22 @@ bool U61_Config::write_str(FILE *file,char *name,char *value)
 
   pos=0;
   while (*value!=0)
-  {
-	  switch (*value)
-	  {
-	  case '\\':
-		buffer_value[pos]='\\';
-		pos++;
-		/*
-		 * no break; instruction, since we want the caracter to
-		 * be added after the \
-		 */
-	  default:
-		buffer_value[pos]=*value;
-		pos++;
-	  }
-	  value++;
-  }
+    {
+      switch (*value)
+	{
+	case '\\':
+	  buffer_value[pos]='\\';
+	  pos++;
+	  /*
+	   * no break; instruction, since we want the caracter to
+	   * be added after the \
+	   */
+	default:
+	  buffer_value[pos]=*value;
+	  pos++;
+	}
+      value++;
+    }
   buffer_value[pos]=0;
 
   strcpy(buffer,name);
