@@ -53,16 +53,16 @@
 /*
  * creates a connection on a specific channel
  */
-U61_Connection::U61_Connection(CL_NetGame *g,CL_NetComputer *c,
+U61_Connection::U61_Connection(CL_NetSession *s,CL_NetComputer c,
 			       int ch,bool give_rights)
 {
-  game=g;
+  session=s;
   channel=ch;
   opened=true;
 
   U61_LOG_DEBUG("Opening connection on channel "<<ch<<"");
 
-  group.computers.push_back(c);
+  group.add(c);
 
   if (give_rights)
     {
@@ -72,7 +72,7 @@ U61_Connection::U61_Connection(CL_NetGame *g,CL_NetComputer *c,
        */
       try 
 	{
-	  game->set_access(ch,&group,
+	  session->set_access(ch,group,
 			   ACCESS_CHANNEL_READ|ACCESS_CHANNEL_WRITE);
 	  U61_LOG_DEBUG("Connection access granted");
 	}
@@ -114,7 +114,7 @@ bool U61_Connection::send(U61_Packet *p)
 
       try
 	{
-	  game->send(channel,&group,message,true);
+	  session->send(channel,group,message,true);
 	}
       catch (CL_Error e)
 	{
@@ -149,7 +149,7 @@ bool U61_Connection::send(char *str,int max)
 
       try
 	{
-	  game->send(channel,&group,message,true);
+	  session->send(channel,group,message,true);
 	}
       catch (CL_Error e)
 	{
@@ -181,7 +181,7 @@ bool U61_Connection::send(int i)
 
       try
 	{
-	  game->send(channel,&group,message,true);
+	  session->send(channel,group,message,true);
 	}
       catch (CL_Error e)
 	{
@@ -210,7 +210,7 @@ bool U61_Connection::send(U61_Event evt)
 
       try
 	{
-	  game->send(channel,&group,message,true);
+	  session->send(channel,group,message,true);
 	}
       catch (CL_Error e)
 	{
@@ -231,7 +231,7 @@ bool U61_Connection::peek()
   bool result=false;
   if (opened)
     {  
-      result=game->peek(channel);
+      result=session->peek(channel);
     }
 
   return result;
@@ -251,7 +251,7 @@ bool U61_Connection::recv(U61_Packet *p)
     {
       try 
 	{
-	  message=game->receive(channel,-1);
+	  message=session->receive(channel,-1);
 
 	  size=message.data.size();
 	  if (size>U61_PACKET_MAX_DATA)
@@ -290,7 +290,7 @@ bool U61_Connection::recv(char *str,int max)
     {
       try 
 	{
-	  message=game->receive(channel,-1);
+	  message=session->receive(channel,-1);
 
 	  size=message.data.size();
 	  if (size>max)
@@ -326,7 +326,7 @@ bool U61_Connection::recv(int *i)
     {
       try 
 	{
-	  message=game->receive(channel,-1);
+	  message=session->receive(channel,-1);
 
 	  size=message.data.size();
 	  if (size!=sizeof(*i))
@@ -367,7 +367,7 @@ bool U61_Connection::recv(U61_Event *evt)
     {
       try 
 	{
-	  message=game->receive(channel,-1);
+	  message=session->receive(channel,-1);
 
 	  size=message.data.size();
 	  if (size!=8)
@@ -397,6 +397,18 @@ bool U61_Connection::recv(U61_Event *evt)
  */
 void U61_Connection::close()
 {
+  char buffer[2];
+
+  /*
+   * We flush the incoming queue
+   */
+  while (peek())
+    {
+      recv(buffer,1);
+    }
+
+  group.disconnect();
+
   opened=false;
 }
 
@@ -409,7 +421,7 @@ bool U61_Connection::is_associated(CL_NetComputer *c)
 {
   bool result=false;
 
-  if (group.computers.front()==c)
+  if (group.get_computers().front()==*c)
     {
       result=true;
     }
@@ -430,3 +442,30 @@ bool U61_Connection::is_associated(CL_NetComputer *c)
 
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
