@@ -46,6 +46,7 @@
 #include "data.h"
 #include "const.h"
 #include "debug.h"
+#include "platform.h"
 
 /*---------------------------------------------------------------------------
  constants
@@ -147,6 +148,13 @@
 U61_Data::U61_Data()
 {
   manager=NULL;
+  
+  /*
+   * We keep the initial working directory in memory, to
+   * chdir back to it later, if needed...
+   */
+  strcpy(initial_dir,U61_Platform::getcwd());
+  strcpy(data_dir,U61_Platform::getcwd());
 }
 
 /*--------------------------------------------------------------------------*/
@@ -197,6 +205,9 @@ void U61_Data::unload()
 bool U61_Data::load1(char *name)
 {
   bool success=true;
+  int len;
+  
+  packed_data=true;
 
   /*
    * creation of the resource manager, which will be
@@ -210,7 +221,27 @@ bool U61_Data::load1(char *name)
    */
   try
     {
-      manager=CL_ResourceManager::create(name,true);
+      /*
+       * We check if the datafile is packed (.dat) or directory based (.scr)
+       */
+      len=strlen(name);
+      if (len>4)
+	{
+	  if (strcmp(name+len-4,".scr")==0 || strcmp(name+len-4,".SCR")==0)
+	    {
+	      packed_data=false;
+	      /*
+	       * Now we store in dir the directory where the datafile is.
+	       * Later we will chdir to this directory, otherwise the
+	       * ClanLib datafile reader whill pathetically fail since
+	       * it opens "." as the main parent directory
+	       */
+	      strcpy(data_dir,name);
+	      U61_Platform::keep_dir_only(data_dir);
+	    }
+	}
+
+      manager=new CL_ResourceManager(name,packed_data);
 
       if (manager!=NULL)
 	{
@@ -317,6 +348,8 @@ bool U61_Data::load2()
 	    {
 	      U61_LOG_ERROR("Unknown error reading datafile, step 2");
 	    }
+	  
+	  manager->load_all();
 	}
       catch(CL_Error e)
 	{
@@ -333,6 +366,25 @@ bool U61_Data::load2()
   return success;
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * chdir to the data directory 
+ */
+void U61_Data::chdir_to_data_dir()
+{
+  U61_Platform::chdir(data_dir);
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * cancels the effects of chdir_to_data_dir
+ */
+void U61_Data::chdir_to_initial_dir()
+{
+  U61_Platform::chdir(initial_dir);
+}
+
+
 /*--------------------------------------------------------------------------*/
 /*
  * loads global properties 
@@ -341,100 +393,100 @@ bool U61_Data::load_properties()
 {
   bool success=true;
 
-  screen_w=CL_Res_Integer::load(U61_DATA_ID_PROPERTY_SCREEN_W,manager);
-  screen_h=CL_Res_Integer::load(U61_DATA_ID_PROPERTY_SCREEN_H,manager);
+  screen_w=CL_Integer(U61_DATA_ID_PROPERTY_SCREEN_W,manager);
+  screen_h=CL_Integer(U61_DATA_ID_PROPERTY_SCREEN_H,manager);
 
   player_w[U61_DATA_SIZE_BIG]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_PLAYER_W_BIG,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_PLAYER_W_BIG,manager);
   player_h[U61_DATA_SIZE_BIG]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_PLAYER_H_BIG,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_PLAYER_H_BIG,manager);
 
   offset_map_x[U61_DATA_SIZE_BIG]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_MAP_X_BIG,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_MAP_X_BIG,manager);
   offset_map_y[U61_DATA_SIZE_BIG]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_MAP_Y_BIG,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_MAP_Y_BIG,manager);
   offset_info_x[U61_DATA_SIZE_BIG]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_INFO_X_BIG,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_INFO_X_BIG,manager);
   offset_info_y[U61_DATA_SIZE_BIG]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_INFO_Y_BIG,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_INFO_Y_BIG,manager);
   offset_squares_x[U61_DATA_SIZE_BIG]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_SQUARES_X_BIG,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_SQUARES_X_BIG,manager);
   offset_squares_y[U61_DATA_SIZE_BIG]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_SQUARES_Y_BIG,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_SQUARES_Y_BIG,manager);
   offset_name_x[U61_DATA_SIZE_BIG]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_NAME_X_BIG,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_NAME_X_BIG,manager);
   offset_name_y[U61_DATA_SIZE_BIG]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_NAME_Y_BIG,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_NAME_Y_BIG,manager);
   offset_score_x[U61_DATA_SIZE_BIG]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_SCORE_X_BIG,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_SCORE_X_BIG,manager);
   offset_score_y[U61_DATA_SIZE_BIG]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_SCORE_Y_BIG,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_SCORE_Y_BIG,manager);
   offset_target_x[U61_DATA_SIZE_BIG]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_TARGET_X_BIG,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_TARGET_X_BIG,manager);
   offset_target_y[U61_DATA_SIZE_BIG]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_TARGET_Y_BIG,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_TARGET_Y_BIG,manager);
   offset_preview_x[U61_DATA_SIZE_BIG]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_PREVIEW_X_BIG,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_PREVIEW_X_BIG,manager);
   offset_preview_y[U61_DATA_SIZE_BIG]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_PREVIEW_Y_BIG,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_PREVIEW_Y_BIG,manager);
   offset_curses_x[U61_DATA_SIZE_BIG]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_CURSES_X_BIG,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_CURSES_X_BIG,manager);
   offset_curses_y[U61_DATA_SIZE_BIG]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_CURSES_Y_BIG,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_CURSES_Y_BIG,manager);
   offset_antidotes_x[U61_DATA_SIZE_BIG]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_ANTIDOTES_X_BIG,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_ANTIDOTES_X_BIG,manager);
   offset_antidotes_y[U61_DATA_SIZE_BIG]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_ANTIDOTES_Y_BIG,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_ANTIDOTES_Y_BIG,manager);
   offset_next_curse_x[U61_DATA_SIZE_BIG]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_NEXT_CURSE_X_BIG,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_NEXT_CURSE_X_BIG,manager);
   offset_next_curse_y[U61_DATA_SIZE_BIG]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_NEXT_CURSE_Y_BIG,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_NEXT_CURSE_Y_BIG,manager);
 
   player_w[U61_DATA_SIZE_SMALL]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_PLAYER_W_SMALL,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_PLAYER_W_SMALL,manager);
   player_h[U61_DATA_SIZE_SMALL]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_PLAYER_H_SMALL,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_PLAYER_H_SMALL,manager);
 
   offset_map_x[U61_DATA_SIZE_SMALL]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_MAP_X_SMALL,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_MAP_X_SMALL,manager);
   offset_map_y[U61_DATA_SIZE_SMALL]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_MAP_Y_SMALL,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_MAP_Y_SMALL,manager);
   offset_info_x[U61_DATA_SIZE_SMALL]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_INFO_X_SMALL,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_INFO_X_SMALL,manager);
   offset_info_y[U61_DATA_SIZE_SMALL]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_INFO_Y_SMALL,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_INFO_Y_SMALL,manager);
   offset_squares_x[U61_DATA_SIZE_SMALL]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_SQUARES_X_SMALL,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_SQUARES_X_SMALL,manager);
   offset_squares_y[U61_DATA_SIZE_SMALL]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_SQUARES_Y_SMALL,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_SQUARES_Y_SMALL,manager);
   offset_name_x[U61_DATA_SIZE_SMALL]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_NAME_X_SMALL,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_NAME_X_SMALL,manager);
   offset_name_y[U61_DATA_SIZE_SMALL]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_NAME_Y_SMALL,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_NAME_Y_SMALL,manager);
   offset_score_x[U61_DATA_SIZE_SMALL]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_SCORE_X_SMALL,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_SCORE_X_SMALL,manager);
   offset_score_y[U61_DATA_SIZE_SMALL]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_SCORE_Y_SMALL,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_SCORE_Y_SMALL,manager);
   offset_target_x[U61_DATA_SIZE_SMALL]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_TARGET_X_SMALL,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_TARGET_X_SMALL,manager);
   offset_target_y[U61_DATA_SIZE_SMALL]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_TARGET_Y_SMALL,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_TARGET_Y_SMALL,manager);
   offset_preview_x[U61_DATA_SIZE_SMALL]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_PREVIEW_X_SMALL,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_PREVIEW_X_SMALL,manager);
   offset_preview_y[U61_DATA_SIZE_SMALL]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_PREVIEW_Y_SMALL,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_PREVIEW_Y_SMALL,manager);
   offset_curses_x[U61_DATA_SIZE_SMALL]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_CURSES_X_SMALL,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_CURSES_X_SMALL,manager);
   offset_curses_y[U61_DATA_SIZE_SMALL]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_CURSES_Y_SMALL,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_CURSES_Y_SMALL,manager);
   offset_antidotes_x[U61_DATA_SIZE_SMALL]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_ANTIDOTES_X_SMALL,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_ANTIDOTES_X_SMALL,manager);
   offset_antidotes_y[U61_DATA_SIZE_SMALL]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_ANTIDOTES_Y_SMALL,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_ANTIDOTES_Y_SMALL,manager);
   offset_next_curse_x[U61_DATA_SIZE_SMALL]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_NEXT_CURSE_X_SMALL,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_NEXT_CURSE_X_SMALL,manager);
   offset_next_curse_y[U61_DATA_SIZE_SMALL]=
-    CL_Res_Integer::load(U61_DATA_ID_PROPERTY_OFFSET_NEXT_CURSE_Y_SMALL,manager);
+    CL_Integer(U61_DATA_ID_PROPERTY_OFFSET_NEXT_CURSE_Y_SMALL,manager);
 
   return success;    
 }
@@ -510,7 +562,7 @@ bool U61_Data::load_musics()
   char buffer[U61_CONST_STRING_SIZE];
   int i;
 
-  nb_music=CL_Res_Integer::load(U61_DATA_ID_MUSIC_NUMBER,manager);
+  nb_music=CL_Integer(U61_DATA_ID_MUSIC_NUMBER,manager);
   if (nb_music>=U61_DATA_NB_MUSIC_MAX)
     {
       nb_music=U61_DATA_NB_MUSIC_MAX-1;
@@ -607,7 +659,7 @@ bool U61_Data::load_maps()
   int i;
   char id[U61_CONST_STRING_SIZE];
 
-  nb_map=CL_Res_Integer::load(U61_DATA_ID_MAP_NUMBER,manager,1);
+  nb_map=CL_Integer(U61_DATA_ID_MAP_NUMBER,manager);
   if (nb_map>=U61_DATA_NB_MAP_MAX)
     {
       nb_map=U61_DATA_NB_MAP_MAX-1;
