@@ -44,6 +44,10 @@
  ---------------------------------------------------------------------------*/
 
 #include <ClanLib/core.h>
+#include <ClanLib/sound.h>
+#include <ClanLib/display.h>
+
+#include "const.h"
 
 /*---------------------------------------------------------------------------
  constants
@@ -56,8 +60,9 @@
 #define U61_DATA_NB_MAP_MAX 128
 #define U61_DATA_NB_MUSIC_MAX 1024
 
-#define U61_DATA_SYMBOL_CURSE "-"
-#define U61_DATA_SYMBOL_ANTIDOTE "+"
+#define U61_DATA_SYMBOL_CURSE_BAD "-"
+#define U61_DATA_SYMBOL_CURSE_GOOD "+"
+#define U61_DATA_SYMBOL_ANTIDOTE "a"
 
 /*---------------------------------------------------------------------------
  classes
@@ -65,88 +70,94 @@
 
 class U61_Data
 {
-public:
-    U61_Data();
-    ~U61_Data();
+ public:
+  U61_Data();
+  ~U61_Data();
 
-    bool load1(char *name);
-    bool load2();
-    void unload();
+  bool load1(char *name);
+  bool load2();
+  void unload();
+  
+  void chdir_to_data_dir();
+  void chdir_to_initial_dir();
 
-    int screen_w;
-    int screen_h;
+  int screen_w;
+  int screen_h;
 
-    int square_w[U61_DATA_NB_SIZE];
-    int square_h[U61_DATA_NB_SIZE];
-    int map_w[U61_DATA_NB_SIZE];
-    int map_h[U61_DATA_NB_SIZE];
-    int info_w[U61_DATA_NB_SIZE];
-    int info_h[U61_DATA_NB_SIZE];
-    int player_w[U61_DATA_NB_SIZE];
-    int player_h[U61_DATA_NB_SIZE];
+  int square_w[U61_DATA_NB_SIZE];
+  int square_h[U61_DATA_NB_SIZE];
+  int map_w[U61_DATA_NB_SIZE];
+  int map_h[U61_DATA_NB_SIZE];
+  int info_w[U61_DATA_NB_SIZE];
+  int info_h[U61_DATA_NB_SIZE];
+  int player_w[U61_DATA_NB_SIZE];
+  int player_h[U61_DATA_NB_SIZE];
 
-    int offset_map_x[U61_DATA_NB_SIZE];
-    int offset_map_y[U61_DATA_NB_SIZE];
-    int offset_info_x[U61_DATA_NB_SIZE];
-    int offset_info_y[U61_DATA_NB_SIZE];
-    int offset_squares_x[U61_DATA_NB_SIZE];
-    int offset_squares_y[U61_DATA_NB_SIZE];
-    int offset_name_x[U61_DATA_NB_SIZE];
-    int offset_name_y[U61_DATA_NB_SIZE];
-    int offset_score_x[U61_DATA_NB_SIZE];
-    int offset_score_y[U61_DATA_NB_SIZE];
-    int offset_target_x[U61_DATA_NB_SIZE];
-    int offset_target_y[U61_DATA_NB_SIZE];
-    int offset_preview_x[U61_DATA_NB_SIZE];
-    int offset_preview_y[U61_DATA_NB_SIZE];
-    int offset_curses_x[U61_DATA_NB_SIZE];
-    int offset_curses_y[U61_DATA_NB_SIZE];
-    int offset_antidotes_x[U61_DATA_NB_SIZE];
-    int offset_antidotes_y[U61_DATA_NB_SIZE];
-    int offset_next_curse_x[U61_DATA_NB_SIZE];
-    int offset_next_curse_y[U61_DATA_NB_SIZE];
+  int offset_map_x[U61_DATA_NB_SIZE];
+  int offset_map_y[U61_DATA_NB_SIZE];
+  int offset_info_x[U61_DATA_NB_SIZE];
+  int offset_info_y[U61_DATA_NB_SIZE];
+  int offset_squares_x[U61_DATA_NB_SIZE];
+  int offset_squares_y[U61_DATA_NB_SIZE];
+  int offset_name_x[U61_DATA_NB_SIZE];
+  int offset_name_y[U61_DATA_NB_SIZE];
+  int offset_score_x[U61_DATA_NB_SIZE];
+  int offset_score_y[U61_DATA_NB_SIZE];
+  int offset_target_x[U61_DATA_NB_SIZE];
+  int offset_target_y[U61_DATA_NB_SIZE];
+  int offset_preview_x[U61_DATA_NB_SIZE];
+  int offset_preview_y[U61_DATA_NB_SIZE];
+  int offset_curses_x[U61_DATA_NB_SIZE];
+  int offset_curses_y[U61_DATA_NB_SIZE];
+  int offset_antidotes_x[U61_DATA_NB_SIZE];
+  int offset_antidotes_y[U61_DATA_NB_SIZE];
+  int offset_next_curse_x[U61_DATA_NB_SIZE];
+  int offset_next_curse_y[U61_DATA_NB_SIZE];
    
-    int nb_map;
-    int nb_music;
+  int nb_map;
+  int nb_music;
 
-    CL_Font *font_menu;
-    CL_Font *font_info[U61_DATA_NB_SIZE];
-    CL_Font *font_symbol[U61_DATA_NB_SIZE];
+  CL_Font *font_menu;
+  CL_Font *font_info[U61_DATA_NB_SIZE];
+  CL_Font *font_symbol[U61_DATA_NB_SIZE];
  
-    CL_SoundBuffer *sound_game_start;
-    CL_SoundBuffer *sound_menu_move;
-    CL_SoundBuffer *sound_menu_validate;
-    CL_SoundBuffer *sound_block_touch;
-    CL_SoundBuffer *sound_block_pattern;
-    CL_SoundBuffer *sound_player_start;
-    CL_SoundBuffer *sound_curse_receive;
-    CL_SoundBuffer *sound_player_loose;
+  CL_SoundBuffer *sound_game_start;
+  CL_SoundBuffer *sound_menu_move;
+  CL_SoundBuffer *sound_menu_validate;
+  CL_SoundBuffer *sound_block_touch;
+  CL_SoundBuffer *sound_block_pattern;
+  CL_SoundBuffer *sound_player_start;
+  CL_SoundBuffer *sound_curse_receive;
+  CL_SoundBuffer *sound_player_loose;
  
-    CL_SoundBuffer *music[U61_DATA_NB_MUSIC_MAX];
+  CL_SoundBuffer *music[U61_DATA_NB_MUSIC_MAX];
  
-    CL_Surface *square[U61_DATA_NB_SQUARE_TYPE][U61_DATA_NB_SIZE];
-    CL_Surface *curse[U61_DATA_NB_SIZE];
-    CL_Surface *anticipation[U61_DATA_NB_SIZE];
-    CL_Surface *explosion[U61_DATA_NB_SIZE];
+  CL_Surface *square[U61_DATA_NB_SQUARE_TYPE][U61_DATA_NB_SIZE];
+  CL_Surface *curse[U61_DATA_NB_SIZE];
+  CL_Surface *anticipation[U61_DATA_NB_SIZE];
+  CL_Surface *explosion[U61_DATA_NB_SIZE];
 
-    CL_Surface *map[U61_DATA_NB_MAP_MAX][U61_DATA_NB_SIZE];
+  CL_Surface *map[U61_DATA_NB_MAP_MAX][U61_DATA_NB_SIZE];
 
-    CL_Surface *back;
-    CL_Surface *shade;
+  CL_Surface *back;
+  CL_Surface *shade;
 
-    CL_Surface *info[U61_DATA_NB_SIZE];
+  CL_Surface *info[U61_DATA_NB_SIZE];
 
-protected:
-    CL_ResourceManager *manager;
+ protected:
+  CL_ResourceManager *manager;
+  bool packed_data;
+  char initial_dir[U61_CONST_STRING_SIZE+1];
+  char data_dir[U61_CONST_STRING_SIZE+1];
 
-    bool load_properties();
-    bool load_fonts();
-    bool load_sounds();
-    bool load_musics();
-    bool load_squares();
-    bool load_maps();
-    bool load_back();
-    bool load_info();
+  bool load_properties();
+  bool load_fonts();
+  bool load_sounds();
+  bool load_musics();
+  bool load_squares();
+  bool load_maps();
+  bool load_back();
+  bool load_info();
 };
 
 #endif
