@@ -39,7 +39,16 @@
  includes
  ---------------------------------------------------------------------------*/
 
+/*
+ * Win32 is just a poor OS which handles long names like s..t, so we have to
+ * use #defines to include strstrea.h instead of strstream.h 8-(
+ */
+#ifdef U61_MSVC
+#include <strstrea.h>
+#else
 #include <strstream.h>
+#endif
+
 #include <fstream.h>
 
 #include <ClanLib/core.h>
