@@ -47,6 +47,12 @@
 
 #include "connection.h"
 
+/*---------------------------------------------------------------------------
+ constants
+ ---------------------------------------------------------------------------*/
+
+#define U61_DISPATCHER_MAX_PLAYER_ID 16
+
 /*---------------------------------------------------------------------------
  classes
  ---------------------------------------------------------------------------*/
@@ -69,21 +75,17 @@ public:
     virtual bool recv(U61_Event *evt);
     virtual bool peek();
 
-    const static int MAX_PLAYER_ID=16;
-
     bool is_player_busy(int player_id);
 
  protected:
-    static const int MAX_AT_ONCE=100;
-
     bool empty_out();
     U61_Event get_out();
     void put_in(U61_Event event,int player_id);
 
-    list<U61_Event> incoming_queue[MAX_PLAYER_ID];
-    list<U61_Event> outgoing_queue;  
+    std::list<U61_Event> incoming_queue[U61_DISPATCHER_MAX_PLAYER_ID];
+    std::list<U61_Event> outgoing_queue;  
 
-    bool busy_flag[MAX_PLAYER_ID];
+    bool busy_flag[U61_DISPATCHER_MAX_PLAYER_ID];
 };
 
 #endif
