@@ -84,10 +84,10 @@ U61_Edit::U61_Edit(char *label, char *val) : U61_MenuItem()
  */
 void U61_Edit::update()
 {
-  char buffer[U61_STRING_SIZE];
+  char buffer[U61_CONST_STRING_SIZE];
 
   strcpy(buffer,name);
-  strcat(buffer,SEPARATOR);
+  strcat(buffer,U61_MENUITEM_SEPARATOR);
   strcat(buffer,value);
 
   set_text(buffer);
@@ -150,7 +150,7 @@ bool U61_Edit::action(int key)
 	      value[i+1]=value[i];
 	    }
 	  value[pos]=ascii;
-	  value[MAX_SIZE]=0;
+	  value[U61_EDIT_MAX_SIZE]=0;
 	  pos++;
 	  changed=true;
 	}
@@ -215,7 +215,7 @@ void U61_Edit::select()
 {
   int len,sel;
 
-  sel=strlen(name)+strlen(SEPARATOR); 
+  sel=strlen(name)+strlen(U61_MENUITEM_SEPARATOR); 
 
   /*
    * We select the char which is under the cursor
