@@ -62,12 +62,10 @@ class U61_EventCopy
   bool empty();
   void put(U61_Event);
  protected:
-  static const int DUMMY_PASS=10;
-
   int dummy_counter;
 
   int player;
-  list<U61_Event> queue;
+  std::list<U61_Event> queue;
 };
 
 #endif
