@@ -125,7 +125,7 @@ bool U61_Game::init(char *filename)
   dispatcher=NULL;
 
   strcpy(exe_name,filename);
-  
+
   U61_Global::config.read();
   
   U61_Script::init();
@@ -136,6 +136,8 @@ bool U61_Game::init(char *filename)
 	(U61_Global::config.data_file);
     }
 
+  U61_Global::data.chdir_to_data_dir();
+  
   if (success)
     {
       success=success && 
@@ -164,7 +166,10 @@ bool U61_Game::init(char *filename)
 void U61_Game::deinit()
 {
   U61_Global::config.write();
+  
   U61_Global::data.unload();
+  
+  U61_Global::data.chdir_to_initial_dir();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -833,7 +838,10 @@ bool U61_Game::standard_init()
 
   time_reset();
 
+  U61_Global::data.chdir_to_initial_dir();
   U61_Platform::open_score_file();
+  U61_Global::data.chdir_to_data_dir();
+  
   U61_Global::score.reset();
 
   ok=ok && U61_Global::config.load_script();
