@@ -91,6 +91,14 @@ U61_RemoteScript U61_Global::remote_script;
  */
 U61_InputMonitor U61_Global::input_monitor;
 
+/*--------------------------------------------------------------------------*/
+/*
+ * This object holds all the scores for the current game. Scores have been
+ * separated from the player/map objects since it easier this way to pass
+ * the information to the menu which displays the score.
+ */
+U61_Score U61_Global::score;
+
 /*---------------------------------------------------------------------------
  functions
  ---------------------------------------------------------------------------*/
