@@ -52,6 +52,7 @@
 #include "layout.h"
 #include "remotescript.h"
 #include "inputmonitor.h"
+#include "score.h"
 
 /*---------------------------------------------------------------------------
  classes
@@ -66,6 +67,7 @@ public:
     static U61_Layout layout;
     static U61_RemoteScript remote_script;
     static U61_InputMonitor input_monitor;
+    static U61_Score score;
 protected:
 };
 
