@@ -51,6 +51,12 @@
 
 #include "key.h"
 
+/*---------------------------------------------------------------------------
+ constants
+ ---------------------------------------------------------------------------*/
+
+#define U61_INPUT_MAX_KEYS      256
+
 /*---------------------------------------------------------------------------
  classes
  ---------------------------------------------------------------------------*/
@@ -67,10 +73,8 @@ public:
     void reset();
     bool empty();
     U61_Event get();
-
-    const static int MAX_KEYS=256;
 protected:
-    list<U61_Event> queue;
+    std::list<U61_Event> queue;
     U61_Key *keys; 
     int keys_size;
 };
