@@ -162,10 +162,10 @@ void U61_InputMonitor::init()
 {
   device = CL_Input::keyboards[0];
 
-  slots.add_slot(CL_Input::sig_button_press.connect
-		 (thCreateSlot(this, &U61_InputMonitor::on_button_press)));
-  slots.add_slot(CL_Input::sig_button_release.connect
-		 (thCreateSlot(this, &U61_InputMonitor::on_button_release)));
+  slot_button_press = CL_Input::sig_button_press.connect
+		 (CL_CreateSlot(this, &U61_InputMonitor::on_button_press));
+  slot_button_release = CL_Input::sig_button_release.connect
+		 (CL_CreateSlot(this, &U61_InputMonitor::on_button_release));
 }
 
 /*--------------------------------------------------------------------------*/
@@ -280,7 +280,21 @@ void U61_InputMonitor::on_button_press(CL_InputDevice *device,
 {
   if (this->device != device) return; // wrong device.
 
-  if (key.ascii>=32 && key.ascii<=127)
+  /*
+   * Now the following test is very important. For all the keys that
+   * return a correct ascii code, we consider this is the right way
+   * to poll the key, and it's usually better than using a scancode,
+   * since keyboards can have different layouts (I personnally have
+   * both AZERTY and QWERTY keyboards at home, and I like it when
+   * games know how to make the difference). *BUT* we exclude the
+   * numbers, since they are usually allways at the same place on
+   * keyboards, and on my AZERTY keyboard, the number keys return
+   * accents, &, # and many other things which _are_ valid ascii
+   * codes, but everyone thinks of the key as being 1 2 or 6.
+   * So numbers are polled by their scancode, that's the point.
+   */ 
+  if (key.ascii>=32 && key.ascii<=127 && 
+      !(key.id>=CL_KEY_0 && key.id<=CL_KEY_9))
     {
       ascii[key.ascii-32].press();
       ascii_time[key.ascii-32]=CL_System::get_time();
@@ -300,7 +314,21 @@ void U61_InputMonitor::on_button_release(CL_InputDevice *device,
 {
   if (this->device != device) return; // wrong device.
 
-  if (key.ascii>=32 && key.ascii<=127)
+  /*
+   * Now the following test is very important. For all the keys that
+   * return a correct ascii code, we consider this is the right way
+   * to poll the key, and it's usually better than using a scancode,
+   * since keyboards can have different layouts (I personnally have
+   * both AZERTY and QWERTY keyboards at home, and I like it when
+   * games know how to make the difference). *BUT* we exclude the
+   * numbers, since they are usually allways at the same place on
+   * keyboards, and on my AZERTY keyboard, the number keys return
+   * accents, &, # and many other things which _are_ valid ascii
+   * codes, but everyone thinks of the key as being 1 2 or 6.
+   * So numbers are polled by their scancode, that's the point.
+   */ 
+  if (key.ascii>=32 && key.ascii<=127 && 
+      !(key.id>=CL_KEY_0 && key.id<=CL_KEY_9))
     {
       ascii[key.ascii-32].release();
       ascii_time[key.ascii-32]=0;
