@@ -43,6 +43,8 @@
  ---------------------------------------------------------------------------*/
 
 #include <ClanLib/core.h>
+#include <ClanLib/signals.h>
+#include <ClanLib/display.h>
 
 #include "keydef.h"
 
@@ -78,7 +80,8 @@ class U61_InputMonitor
   U61_KeyDef scancode[CL_NUM_KEYS];
   char ascii_labels[96*2];  
 
-  thSlotContainer slots;
+  CL_Slot slot_button_press;
+  CL_Slot slot_button_release;
   void on_button_press(CL_InputDevice *device, const CL_Key &key);
   void on_button_release(CL_InputDevice *device, const CL_Key &key);
 
