@@ -79,10 +79,10 @@ U61_KeyChoose::U61_KeyChoose(char *label, int *val) : U61_MenuItem()
  */
 void U61_KeyChoose::update()
 {
-  char buffer[U61_STRING_SIZE];
+  char buffer[U61_CONST_STRING_SIZE];
 
   strcpy(buffer,name);
-  strcat(buffer,SEPARATOR);
+  strcat(buffer,U61_MENUITEM_SEPARATOR);
   if (waiting)
     {
       strcat(buffer,"press a key");
@@ -132,7 +132,7 @@ void U61_KeyChoose::select()
 {
   int start;
 
-  start=strlen(name)+strlen(SEPARATOR);
+  start=strlen(name)+strlen(U61_MENUITEM_SEPARATOR);
 
   select_right(start);
 }
