@@ -47,6 +47,14 @@
 
 #include "layoutitem.h"
 
+/*---------------------------------------------------------------------------
+ constants
+ ---------------------------------------------------------------------------*/
+
+#define U61_LAYOUT_NB_PLAYERS_LOCAL 4
+#define U61_LAYOUT_NB_PLAYERS_NET_LOCAL 2
+#define U61_LAYOUT_NB_PLAYERS_TOTAL 10
+
 /*---------------------------------------------------------------------------
  classes
  ---------------------------------------------------------------------------*/
@@ -78,19 +86,16 @@ class U61_Layout
                          
   void draw();
 
-  static const int NB_PLAYERS_LOCAL=4;
-  static const int NB_PLAYERS_NET_LOCAL=2;
-  static const int NB_PLAYERS_TOTAL=10;
-
   int check_player_id(int old_id,int own_id);
   int get_prev_player_id(int old_id,int own_id);
   int get_next_player_id(int old_id,int own_id);
     
  protected:
-  static const int SHUFFLE_COUNT=1000;
+  int change_counter;
 
-  U61_LayoutItem items[NB_PLAYERS_TOTAL];
-  CL_Canvas *background;
+  U61_LayoutItem items[U61_LAYOUT_NB_PLAYERS_TOTAL];
+  CL_Surface *back_surface;
+  CL_Canvas *back_canvas;
     
   void init_network_common(U61_Player *net);
   bool exists_changed_background();
