@@ -54,9 +54,21 @@
 #include "music.h"
 
 /*---------------------------------------------------------------------------
- globals
+ constants
  ---------------------------------------------------------------------------*/
 
+#define U61_MAP_SPEED_SCALE 1000
+#define U61_MAP_ACCEL_SCALE 1000000
+#define U61_MAP_MAX_SYSTEM_SPEED 50
+#define U61_MAP_MAX_SYSTEM_ACCEL 15
+#define U61_MAP_MAX_SCORE 1000000
+#define U61_MAP_TIME_CALLBACK_1_DELAY 100
+#define U61_MAP_TIME_CALLBACK_10_DELAY 10
+#define U61_MAP_TIME_CALLBACK_100_DELAY 1
+#define U61_MAP_CHECK_TARGET_DELAY 100
+#define U61_MAP_CHECK_CURSE_DELAY 100
+#define U61_MAP_ANTICIPATE_MAX 1000
+
 /*--------------------------------------------------------------------------*/
 /* 
  * these arrays contain constants used for speeds, this way one can
@@ -166,7 +178,7 @@ void U61_Map::begin()
     }        
   for (i=0;i<U61_MAP_MAX_CURSE_ID;++i)
     {
-      curse_begin[i]=-1;
+      registered_curse[i].reset();
     }        
   change_background();
 
@@ -222,7 +234,7 @@ bool U61_Map::is_active()
  */
 void U61_Map::set_active(int time)
 {
-  reset();
+  begin();
   map_time=time;
   active=true;
 }
@@ -441,13 +453,14 @@ int U61_Map::get_curse_age(int i)
 
   if (i>=0 && i<U61_MAP_MAX_CURSE_ID)
     {
-      if (curse_begin[i]<0 || map_time>curse_end[i])
+      if ((!registered_curse[i].active) 
+	  || map_time>registered_curse[i].end)
 	{
 	  age=-1;
 	}
       else
 	{
-          age=((map_time-curse_begin[i])/U61_TIME_ONE_SECOND);
+          age=((map_time-registered_curse[i].begin));
 	}
     }
 
@@ -459,7 +472,7 @@ int U61_Map::get_curse_age(int i)
  * Registers a persistent curse. After this, calls to get_curse_age
  * will return how long ago the curse has been registered
  */
-void U61_Map::register_curse(int i, int length)
+void U61_Map::register_curse(int i, int length, bool good)
 {
   if (i>=0 && i<U61_MAP_MAX_CURSE_ID)
     {
@@ -469,10 +482,12 @@ void U61_Map::register_curse(int i, int length)
        */
       if (length<=0)
 	{
-	  length=36000;
+	  length=3600000;
 	}
-      curse_begin[i]=map_time;
-      curse_end[i]=map_time+length*U61_TIME_ONE_SECOND;
+      registered_curse[i].begin=map_time;
+      registered_curse[i].end=map_time+length;
+      registered_curse[i].active=true;
+      registered_curse[i].good=good;
       U61_LOG_DEBUG("Registering "<<i<<" begin="<<curse_begin[i]<<" end="<<curse_end[i]);
     }
 }
@@ -485,7 +500,7 @@ void U61_Map::cancel_curse(int i)
 {
   if (i>=0 && i<U61_MAP_MAX_CURSE_ID)
     {
-      curse_begin[i]=-1;
+      registered_curse[i].active=false;
     }
 }
 
@@ -494,7 +509,7 @@ void U61_Map::cancel_curse(int i)
  * Returns the oldest curse available
  * Returns -1 if none existing
  */
-int U61_Map::get_oldest_curse()
+int U61_Map::get_oldest_curse(bool good)
 {
   int oldest;
   int i;
@@ -505,7 +520,7 @@ int U61_Map::get_oldest_curse()
   for (i=0;i<U61_MAP_MAX_CURSE_ID;++i)
     {
       if (get_curse_age(i)>=0 &&
-	  curse_begin[i]<=map_time)
+	  registered_curse[i].good==good)
 	{ 
 	  oldest=map_time;
           result=i;
@@ -519,7 +534,7 @@ int U61_Map::get_oldest_curse()
 /*
  * gets the number of persisten curses which are affecting the map
  */
-int U61_Map::get_nb_curse()
+int U61_Map::get_nb_curse(bool good)
 {
   int nb;
   int i;
@@ -527,7 +542,8 @@ int U61_Map::get_nb_curse()
   nb=0;
   for (i=0;i<U61_MAP_MAX_CURSE_ID;++i)
     {
-      if (get_curse_age(i)>=0)
+      if (get_curse_age(i)>=0 &&
+	  registered_curse[i].good==good)
 	{
 	  nb++;
 	}
@@ -720,9 +736,17 @@ void U61_Map::compute_next()
   map_time++;
   curse_counter++;
   update_explosions();
-  if (!(map_time%U61_MAP_TIME_CALLBACK_DELAY))
+  if (!(map_time%U61_MAP_TIME_CALLBACK_1_DELAY))
     {
-      time_callback();
+      time_callback_1();
+    }
+  if (!(map_time%U61_MAP_TIME_CALLBACK_10_DELAY))
+    {
+      time_callback_10();
+    }
+  if (!(map_time%U61_MAP_TIME_CALLBACK_100_DELAY))
+    {
+      time_callback_100();
     }
   if (!(map_time%U61_MAP_CHECK_TARGET_DELAY))
     {
@@ -1626,7 +1650,10 @@ void U61_Map::match_pattern()
         {
 	  if (match_count==0 && !silent)
             {
-	      U61_Sound::play_block_touch();
+	      if (!silent)
+		{
+		  U61_Sound::play_block_touch();
+		}
             }
 	  matching=false;
         }
@@ -1635,14 +1662,48 @@ void U61_Map::match_pattern()
 
 /*--------------------------------------------------------------------------*/
 /*
- * calls the lua function time_callback
+ * calls the lua function time_callback_1
  * its purpose is to provide control to lua scripts over the game
  * in general. since this function is called on a regular basis
  * it's possible for instance to make the block change now & then
  */
-void U61_Map::time_callback()
+void U61_Map::time_callback_1()
 {
-  U61_Script::time_callback(this,&block);
+  U61_Script::time_callback_1(this,&block);
+  /*
+   * The call to check_block is very important since time_callback
+   * has full rights on the map and block.
+   */
+  check_block();
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * calls the lua function time_callback_10
+ * its purpose is to provide control to lua scripts over the game
+ * in general. since this function is called on a regular basis
+ * it's possible for instance to make the block change now & then
+ */
+void U61_Map::time_callback_10()
+{
+  U61_Script::time_callback_10(this,&block);
+  /*
+   * The call to check_block is very important since time_callback
+   * has full rights on the map and block.
+   */
+  check_block();
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * calls the lua function time_callback_100
+ * its purpose is to provide control to lua scripts over the game
+ * in general. since this function is called on a regular basis
+ * it's possible for instance to make the block change now & then
+ */
+void U61_Map::time_callback_100()
+{
+  U61_Script::time_callback_100(this,&block);
   /*
    * The call to check_block is very important since time_callback
    * has full rights on the map and block.
