@@ -52,6 +52,7 @@
 #include "block.h"
 #include "event.h"
 #include "data.h"
+#include "registeredcurse.h"
 
 /*---------------------------------------------------------------------------
  constants
@@ -62,17 +63,8 @@
 #define U61_MAP_NAME_SIZE 8
 #define U61_MAP_NB_GLOBAL 1000
 #define U61_MAP_MAX_CURSE_ID 1000
-#define U61_MAP_SPEED_SCALE 1000
-#define U61_MAP_ACCEL_SCALE 1000000
-#define U61_MAP_TIME_CALLBACK_DELAY 10
-#define U61_MAP_CHECK_TARGET_DELAY 100
-#define U61_MAP_CHECK_CURSE_DELAY 100
-#define U61_MAP_ANTICIPATE_MAX 1000
 #define U61_MAP_MAX_USER_SPEED 20
 #define U61_MAP_MAX_USER_ACCEL 10
-#define U61_MAP_MAX_SYSTEM_SPEED 50
-#define U61_MAP_MAX_SYSTEM_ACCEL 15
-#define U61_MAP_MAX_SCORE 100000000
 
 /*---------------------------------------------------------------------------
  classes
@@ -115,10 +107,10 @@ public:
     int get_global(int i);
 
     int get_curse_age(int i);
-    void register_curse(int i,int length);
+    void register_curse(int i,int length,bool good);
     void cancel_curse(int i);
-    int get_oldest_curse();
-    int get_nb_curse();
+    int get_oldest_curse(bool good);
+    int get_nb_curse(bool good);
     int get_nb_antidote();
     void add_antidote();
     void delete_antidote();
@@ -175,8 +167,7 @@ protected:
     std::list<U61_Event> auto_events;
     std::list<U61_Event> request_events;
     int global_val[U61_MAP_NB_GLOBAL];
-    int curse_begin[U61_MAP_MAX_CURSE_ID];
-    int curse_end[U61_MAP_MAX_CURSE_ID];
+    U61_RegisteredCurse registered_curse[U61_MAP_MAX_CURSE_ID];
     char name[U61_MAP_NAME_SIZE+1];
 
     int player_id;
@@ -237,7 +228,9 @@ protected:
     void loose();
 
     void match_pattern();
-    void time_callback();
+    void time_callback_1();
+    void time_callback_10();
+    void time_callback_100();
 
     void check_speed();
     void check_accel();
