@@ -45,6 +45,14 @@
 
 #include "menuitem.h"
 
+
+/*---------------------------------------------------------------------------
+ constants
+ ---------------------------------------------------------------------------*/
+
+#define U61_MENU_BOTTOM_MESSAGE_NB          10
+#define U61_MENU_BOTTOM_MESSAGE_DELAY        2
+
 /*---------------------------------------------------------------------------
  classes
  ---------------------------------------------------------------------------*/
@@ -73,7 +81,7 @@ class U61_Menu
   void unshade();
 
  protected:
-  vector<U61_MenuItem *> items;
+  std::vector<U61_MenuItem *> items;
   U61_Menu *parent_menu;    
   int selection;
   char *top_message;
@@ -86,12 +94,10 @@ class U61_Menu
   void draw_bottom_message();
   void init_bottom_message();
 
-  const static int BOTTOM_MESSAGE_NB=10;
-  const static int BOTTOM_MESSAGE_DELAY=2;
   static int current_bottom_message;
   static int bottom_message_start_time;
   static int bottom_message_width;
-  static char *bottom_message[BOTTOM_MESSAGE_NB];
+  static char *bottom_message[U61_MENU_BOTTOM_MESSAGE_NB];
 };
 
 #endif
