@@ -26,9 +26,12 @@
 #include "debug.h"
 
 /*---------------------------------------------------------------------------
- globals
+ constants
  ---------------------------------------------------------------------------*/
 
+#define U61_MENUINPUT_MOUSE_DELAY       50
+#define U61_MENUINPUT_REPEAT_FIRST      50
+#define U61_MENUINPUT_REPEAT_STANDARD   15
 
 /*---------------------------------------------------------------------------
  functions
@@ -38,7 +41,7 @@
 /* 
  * creation of a menu input object
  */ 
-U61_MenuInput::U61_MenuInput() : U61_Input(U61_InputMonitor::NUM_KEYS)
+U61_MenuInput::U61_MenuInput() : U61_Input(U61_INPUTMONITOR_NUM_KEYS)
 {
   init();
 }
@@ -63,9 +66,9 @@ void U61_MenuInput::init()
   mouse_last_fired=-1;
   mouse_y=-1;
 
-  for (i=0;i<U61_InputMonitor::NUM_KEYS;++i)
+  for (i=0;i<U61_INPUTMONITOR_NUM_KEYS;++i)
     {
-      key.init(i,i,REPEAT_FIRST,REPEAT_STANDARD);
+      key.init(i,i,U61_MENUINPUT_REPEAT_FIRST,U61_MENUINPUT_REPEAT_STANDARD);
       set_key(i,key);
     } 
 }
@@ -86,6 +89,13 @@ void U61_MenuInput::poll_mouse()
     {
       mouse_y=-1;
     }
+
+  /*
+   * For now this mouse support just sucks, so I have disabled it,
+   * so that people do not think the GUI is buggy. It's better for
+   * everyone to use the keyboard only for now...
+   */
+  mouse_y=-1;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -98,7 +108,7 @@ int U61_MenuInput::get_mouse_y()
   int time;
 
   time=U61_Time::for_effect();
-  if (time-mouse_last_fired>MOUSE_DELAY)
+  if (time-mouse_last_fired>U61_MENUINPUT_MOUSE_DELAY)
     {
       mouse_last_fired=time;
       result=mouse_y;
