@@ -52,6 +52,12 @@
 
 #include "letter.h"
 
+/*---------------------------------------------------------------------------
+ constants
+ ---------------------------------------------------------------------------*/
+
+#define U61_MENUITEM_SEPARATOR " : "
+
 /*---------------------------------------------------------------------------
  classes
  ---------------------------------------------------------------------------*/
@@ -80,9 +86,8 @@ class U61_MenuItem
 
   bool is_mouse_in(int y);
  protected:
-  vector<U61_Letter> text;    
+  std::vector<U61_Letter> text;    
   bool selected;
-  static char *const SEPARATOR=" : ";
   int mouse_up_limit;
   int mouse_down_limit;
 };
