@@ -55,6 +55,10 @@ class U61_Platform
   static char *get_data_path();
 
  public:
+  static char *getcwd();
+  static void chdir(char *dir);
+  static void keep_dir_only(char *path);
+
   static char *get_builtin_theme_path();
   static char *get_builtin_script_path();
   static char *get_user_theme_path();
