@@ -39,14 +39,19 @@
  includes
  ---------------------------------------------------------------------------*/
 
+#include <ClanLib/core.h>
+#include <ClanLib/lua.h>
+#include <ClanLib/display.h>
+#include <ClanLib/sound.h>
+#include <ClanLib/network.h>
+#include <ClanLib/mikmod.h>
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <dirent.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <syslog.h>
-#include <ClanLib/mikmod.h>
-#include <ClanLib/lua.h>
 
 #include "platform.h"
 #include "const.h"
@@ -88,9 +93,10 @@ static char *scan_ext=NULL;
  * binary exe that is installed in /usr/bin and a custome built datafile
  * which is in /usr/local/share...
  */
-#define NB_STANDARD_PATHS 5
+#define NB_STANDARD_PATHS 6
 static char *standard_paths[NB_STANDARD_PATHS]=
 {
+  "../share/u61/",
   U61_INSTALL_DATA_PATH,
   "/usr/local/share/u61/",
   "/usr/share/u61/",
@@ -102,6 +108,56 @@ static char *standard_paths[NB_STANDARD_PATHS]=
  functions
  ---------------------------------------------------------------------------*/
 
+/*--------------------------------------------------------------------------*/
+/*
+ * returns the current working directory
+ */
+char *U61_Platform::getcwd()
+{
+  static char buffer[U61_CONST_STRING_SIZE]; 
+
+  buffer[0]='.';
+  buffer[1]='\0';
+  ::getcwd(buffer,sizeof(buffer));
+
+  return buffer;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Changes the current working directory.
+ * This is very usefull to be able to load .scr like datafiles, since at the
+ * time I'm writing these lines ClanLib requires that the .scr is in the
+ * current working directory.
+ */
+void U61_Platform::chdir(char *dir)
+{
+  U61_LOG_DEBUG("chdir to "<<dir);
+  ::chdir(dir);
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * keeps the directory only in a /dir1/dir2/path.ext string
+ */
+void U61_Platform::keep_dir_only(char *path)
+{
+  int len;
+  bool found=false;
+
+  while ((len=strlen(path))>0 && !found)
+    {
+      if (path[len-1]=='/')
+	{
+	  found=true;
+	}
+      else
+	{
+	  path[len-1]='\0';
+	}
+    }
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * returns the user path (/home/ufoot/.u61/ for instance)
@@ -414,9 +470,9 @@ void U61_Platform::exec(char *file)
 
   CL_Lua::close();
   CL_SetupMikMod::deinit();
-  CL_SetupCore::deinit_network();    
-  CL_SetupCore::deinit_sound();
-  CL_SetupCore::deinit_display();
+  CL_SetupNetwork::deinit();    
+  CL_SetupSound::deinit();
+  CL_SetupDisplay::deinit();
   CL_SetupCore::deinit();
 
   /*
@@ -465,6 +521,8 @@ void U61_Platform::open_score_file()
 {
   char buffer[U61_CONST_STRING_SIZE];
 
+  create_user_dir();
+  
   if (score_file==NULL)
     {
       strcpy (buffer,get_user_path());
@@ -530,8 +588,10 @@ void U61_Platform::dump_score(char *text)
 void U61_Platform::open_log_files()
 {
   openlog("u61",LOG_PID,LOG_USER);
+  
+  create_user_dir();  
 
-#ifdef DEBUG
+#ifdef U61_DEBUG
   char buffer[U61_CONST_STRING_SIZE];
 
   if (debug_file==NULL)
@@ -551,7 +611,7 @@ void U61_Platform::open_log_files()
  */
 void U61_Platform::close_log_files()
 {
-#ifdef DEBUG
+#ifdef U61_DEBUG
   if (debug_file!=NULL)
     {
       fclose(debug_file);
@@ -569,7 +629,7 @@ void U61_Platform::log_to_error_file(char *text)
 {
   syslog(LOG_ERR,"error: %s",text);
 
-#ifdef DEBUG
+#ifdef U61_DEBUG
   if (debug_file!=NULL)
     {
       fprintf(debug_file,"*;error  ;%25s;%-5d;%s\n","unknown",0,text);
@@ -585,7 +645,7 @@ void U61_Platform::log_to_warning_file(char *text)
 {
   syslog(LOG_WARNING,"warning: %s",text);
 
-#ifdef DEBUG
+#ifdef U61_DEBUG
   if (debug_file!=NULL)
     {
       fprintf(debug_file,"*;warning;%25s;%-5d;%s\n","unknown",0,text);
@@ -599,7 +659,7 @@ void U61_Platform::log_to_warning_file(char *text)
  */
 void U61_Platform::log_to_message_file(char *text)
 {
-#ifdef DEBUG
+#ifdef U61_DEBUG
   if (debug_file!=NULL)
     {
       fprintf(debug_file," ;message;%25s;%-5d;%s\n","unknown",0,text);
@@ -613,7 +673,7 @@ void U61_Platform::log_to_message_file(char *text)
  */
 void U61_Platform::log_to_debug_file(char *text,char *file,int line)
 {
-#ifdef DEBUG
+#ifdef U61_DEBUG
   if (debug_file!=NULL)
     {
       fprintf(debug_file," ;debug  ;%25s;%-5d;%s\n",file,line,text);
