@@ -39,9 +39,16 @@
  includes
  ---------------------------------------------------------------------------*/
 
+#ifdef U61_MSVC
+
 #include <stdlib.h>
 #include <time.h>
 #include <process.h>
+#include <direct.h>
+#include <ClanLib/core.h>
+#include <ClanLib/network.h>
+#include <ClanLib/sound.h>
+#include <ClanLib/display.h>
 #include <ClanLib/mikmod.h>
 #include <ClanLib/lua.h>
 
@@ -85,21 +92,21 @@ static FILE *trace_file=NULL;
  * should be findable on http://alleg.sourceforge.net/
  */
 typedef struct FFIND_INFO {
-   struct _finddata_t info;
-   long handle;
-   int attrib;
-   int last;
+  struct _finddata_t info;
+  long handle;
+  int attrib;
+  int last;
 } FFIND_INFO;
 static void *find_info=NULL;
 
 /* emulate the FA_* flags for platforms that don't already have them */
 #ifndef FA_RDONLY
-   #define FA_RDONLY       1
-   #define FA_HIDDEN       2
-   #define FA_SYSTEM       4
-   #define FA_LABEL        8
-   #define FA_DIREC        16
-   #define FA_ARCH         32
+#define FA_RDONLY       1
+#define FA_HIDDEN       2
+#define FA_SYSTEM       4
+#define FA_LABEL        8
+#define FA_DIREC        16
+#define FA_ARCH         32
 #endif
 
 /* life would be so easy if compilers would all use the same names! */
@@ -124,41 +131,41 @@ void _al_findclose(void *dta);
  */
 void *_al_findfirst(char *name, int attrib)
 {
-   FFIND_INFO *info;
-//   int a;
+  FFIND_INFO *info;
+  //   int a;
 
-   info = (FFIND_INFO *) malloc(sizeof(FFIND_INFO));
+  info = (FFIND_INFO *) malloc(sizeof(FFIND_INFO));
 
-   if (info!=NULL)
-   {
-   info->attrib = attrib;
-   info->last=0;
+  if (info!=NULL)
+    {
+      info->attrib = attrib;
+      info->last=0;
 
-   if ((info->handle = _findfirst(name, &info->info)) < 0) {
-      free(info);
-      return NULL;
-   }
-/*
-   a = info->info.attrib & (FA_HIDDEN | FA_SYSTEM | FA_LABEL | FA_DIREC);
-
-   if ((a & attrib) != a) {
-      if (_al_findnext(info, nameret, aret) != 0) {
-	 _findclose(info->handle);
-	 free(info);
-	 return NULL;
+      if ((info->handle = _findfirst(name, &info->info)) < 0) {
+	free(info);
+	return NULL;
       }
-      else
-	 return info;
-   }
+      /*
+	a = info->info.attrib & (FA_HIDDEN | FA_SYSTEM | FA_LABEL | FA_DIREC);
 
-//   do_uconvert(info->info.name, U_ASCII, nameret, U_CURRENT, -1);
+	if ((a & attrib) != a) {
+	if (_al_findnext(info, nameret, aret) != 0) {
+	_findclose(info->handle);
+	free(info);
+	return NULL;
+	}
+	else
+	return info;
+	}
+
+	//   do_uconvert(info->info.name, U_ASCII, nameret, U_CURRENT, -1);
 	strcpy(nameret,info->info.name);
 
-   if (aret)
-      *aret = info->info.attrib;
-*/   }
+	if (aret)
+	*aret = info->info.attrib;
+	*/   }
 
-   return info;
+  return info;
 }
 
 
@@ -168,36 +175,36 @@ void *_al_findfirst(char *name, int attrib)
  */
 int _al_findnext(void *dta, char *nameret, int *aret)
 {
-   FFIND_INFO *info = (FFIND_INFO *) dta;
-   int a;
+  FFIND_INFO *info = (FFIND_INFO *) dta;
+  int a;
 
-   if (info->last!=0)
-   {
-	   return -1;
-   }
+  if (info->last!=0)
+    {
+      return -1;
+    }
 
-   a = info->info.attrib & (FA_HIDDEN | FA_SYSTEM | FA_LABEL | FA_DIREC);
-    while ((a & info->attrib) != a) {
-      if (_findnext(info->handle, &info->info) != 0) {
-	 return -1;
-      }
+  a = info->info.attrib & (FA_HIDDEN | FA_SYSTEM | FA_LABEL | FA_DIREC);
+  while ((a & info->attrib) != a) {
+    if (_findnext(info->handle, &info->info) != 0) {
+      return -1;
+    }
 
-      a = info->info.attrib & (FA_HIDDEN | FA_SYSTEM | FA_LABEL | FA_DIREC);
+    a = info->info.attrib & (FA_HIDDEN | FA_SYSTEM | FA_LABEL | FA_DIREC);
 
-   }
+  }
 
-//   do_uconvert(info->info.name, U_ASCII, nameret, U_CURRENT, -1);
-	strcpy(nameret,info->info.name);
+  //   do_uconvert(info->info.name, U_ASCII, nameret, U_CURRENT, -1);
+  strcpy(nameret,info->info.name);
 
-   if (aret)
-      *aret = info->info.attrib;
+  if (aret)
+    *aret = info->info.attrib;
 
-	if (_findnext(info->handle, &info->info) != 0)
-	{
-		info->last=1;
-	}
+  if (_findnext(info->handle, &info->info) != 0)
+    {
+      info->last=1;
+    }
 
-   return 0;
+  return 0;
 }
 
 /* _al_findclose:
@@ -205,10 +212,10 @@ int _al_findnext(void *dta, char *nameret, int *aret)
  */
 void _al_findclose(void *dta)
 {
-   FFIND_INFO *info = (FFIND_INFO *) dta;
+  FFIND_INFO *info = (FFIND_INFO *) dta;
 
-   _findclose(info->handle);
-   free(info);
+  _findclose(info->handle);
+  free(info);
 }
 
 
@@ -218,6 +225,56 @@ void _al_findclose(void *dta)
  functions
  ---------------------------------------------------------------------------*/
 
+/*--------------------------------------------------------------------------*/
+/*
+ * returns the current working directory
+ */
+char *U61_Platform::getcwd()
+{
+  static char buffer[U61_CONST_STRING_SIZE]; 
+  
+  buffer[0]='.';
+  buffer[1]='\0';
+  ::getcwd(buffer,sizeof(buffer));
+  
+  return buffer;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Changes the current working directory.
+ * This is very usefull to be able to load .scr like datafiles, since at the
+ * time I'm writing these lines ClanLib requires that the .scr is in the
+ * current working directory.
+ */
+void U61_Platform::chdir(char *dir)
+{
+  U61_LOG_DEBUG("chdir to "<<dir);
+  ::chdir(dir);
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * keeps the directory only in a /dir1/dir2/path.ext string
+ */
+void U61_Platform::keep_dir_only(char *path)
+{
+  int len;
+  bool found=false;
+  
+  while ((len=strlen(path))>0 && !found)
+    {
+      if (path[len-1]=='\\' || path[len-1]=='/')
+	{
+	  found=true;
+	}
+      else
+	{
+	  path[len-1]='\0';
+	}
+    }
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * returns the path where user data are stored, needs to be writeable
@@ -226,7 +283,7 @@ char *U61_Platform::get_user_path()
 {
   static char buffer[U61_CONST_STRING_SIZE]; 
 
-  strcpy(buffer,".\\");
+  strcpy(buffer,"data\\user\\");
 
   return buffer;
 }
@@ -239,7 +296,7 @@ char *U61_Platform::get_data_path()
 {
   static char buffer[U61_CONST_STRING_SIZE]; 
 
-  strcpy(buffer,".\\");	
+  strcpy(buffer,"data\\builtin\\");	
 
   return buffer;
 }
@@ -253,7 +310,7 @@ char *U61_Platform::get_builtin_theme_path()
   static char buffer[U61_CONST_STRING_SIZE];
 
   strcpy(buffer,get_data_path());
-  strcat(buffer,"builtin-theme\\");
+  strcat(buffer,"theme\\");
 
   return buffer;
 }
@@ -267,7 +324,7 @@ char *U61_Platform::get_builtin_script_path()
   static char buffer[U61_CONST_STRING_SIZE];
 
   strcpy(buffer,get_data_path());
-  strcat(buffer,"builtin-script\\");
+  strcat(buffer,"script\\");
 
   return buffer;
 }
@@ -281,7 +338,7 @@ char *U61_Platform::get_user_theme_path()
   static char buffer[U61_CONST_STRING_SIZE];
 
   strcpy(buffer,get_user_path());
-  strcat(buffer,"user-theme\\");
+  strcat(buffer,"theme\\");
 
   return buffer;
 }
@@ -295,7 +352,7 @@ char *U61_Platform::get_user_script_path()
   static char buffer[U61_CONST_STRING_SIZE];
 
   strcpy(buffer,get_user_path());
-  strcat(buffer,"user-script\\");
+  strcat(buffer,"script\\");
 
   return buffer;
 }
@@ -370,9 +427,9 @@ bool U61_Platform::open_dir(char *dir, char *ext)
   sprintf(buffer,"%s*%s",dir,ext);
   find_info=_al_findfirst(buffer,0);
   if (find_info!=NULL)
-  {
-	ok=true;
-  }
+    {
+      ok=true;
+    }
 
   return ok;
 }
@@ -388,9 +445,9 @@ char *U61_Platform::next_file()
   int attrib;
 
   if (_al_findnext(find_info,buffer,&attrib)==0)
-  {
-	result=buffer;
-  }
+    {
+      result=buffer;
+    }
 
   return result;
 }
@@ -404,10 +461,10 @@ bool U61_Platform::close_dir()
   bool ok=false;
 
   if (find_info!=NULL)
-  {
-	_al_findclose(find_info);
-	find_info=NULL;
-  }
+    {
+      _al_findclose(find_info);
+      find_info=NULL;
+    }
   ok=true;
 
   return ok;
@@ -420,19 +477,19 @@ bool U61_Platform::close_dir()
  */
 bool U61_Platform::create_user_dir()
 {
-    bool result=false;
-
-    /*
-	 * for now the user files are simply stored in ".\" so the
-	 * directory dos not need to be created. Later, U61 might use
-	 * c:\windows\profile\user\u61 but it's not the case yet...
-	 */
-	result=true;
-
-	return true;
+  bool ok=true;
+  
+  /*
+   * For now we _always_ create the directories. It does
+   * no harm to re-create a directory anyway...
+   */
+  ::mkdir(get_user_path());
+  ::mkdir(get_user_script_path());
+  ::mkdir(get_user_theme_path());
+  
+  return ok;
 }
 
-
 /*--------------------------------------------------------------------------*/
 /*
  * Quits U61 and launches "file"
@@ -441,16 +498,16 @@ bool U61_Platform::create_user_dir()
 void U61_Platform::exec(char *file)
 {
   char buffer[U61_CONST_STRING_SIZE];
-//  int len;
+  //  int len;
 
   U61_LOG_MESSAGE("Restarting...");
   U61_Debug::deinit();
 
   CL_Lua::close();
   CL_SetupMikMod::deinit();
-  CL_SetupCore::deinit_network();    
-  CL_SetupCore::deinit_sound();
-  CL_SetupCore::deinit_display();
+  CL_SetupNetwork::deinit();    
+  CL_SetupSound::deinit();
+  CL_SetupDisplay::deinit();
   CL_SetupCore::deinit();
 
   /*
@@ -480,6 +537,8 @@ void U61_Platform::exec(char *file)
 void U61_Platform::open_score_file()
 {
   char buffer[U61_CONST_STRING_SIZE];
+  
+  create_user_dir();
 
   if (score_file==NULL)
     {
@@ -546,6 +605,8 @@ void U61_Platform::dump_score(char *text)
 void U61_Platform::open_log_files()
 {
   char buffer[U61_CONST_STRING_SIZE];
+  
+  create_user_dir();
 
   if (trace_file==NULL)
     {
@@ -555,7 +616,7 @@ void U61_Platform::open_log_files()
       trace_file=fopen(buffer,"w");
     }
 
-#ifdef DEBUG
+#ifdef U61_DEBUG
   if (debug_file==NULL)
     {
       strcpy (buffer,get_user_path());
@@ -580,7 +641,7 @@ void U61_Platform::close_log_files()
   trace_file=NULL;
 
 
-#ifdef DEBUG
+#ifdef U61_DEBUG
   if (debug_file!=NULL)
     {
       fclose(debug_file);
@@ -600,7 +661,7 @@ void U61_Platform::log_to_error_file(char *text)
     {
       fprintf(trace_file,"ERROR! %s\n",text);
     }
-#ifdef DEBUG
+#ifdef U61_DEBUG
   if (debug_file!=NULL)
     {
       fprintf(debug_file,"*;error  ;%25s;%-5d;%s\n","unknown",0,text);
@@ -618,7 +679,7 @@ void U61_Platform::log_to_warning_file(char *text)
     {
       fprintf(trace_file,"WARNING! %s\n",text);
     }
-#ifdef DEBUG
+#ifdef U61_DEBUG
   if (debug_file!=NULL)
     {
       fprintf(debug_file,"*;warning;%25s;%-5d;%s\n","unknown",0,text);
@@ -636,7 +697,7 @@ void U61_Platform::log_to_message_file(char *text)
     {
       fprintf(trace_file,"%s\n",text);
     }
-#ifdef DEBUG
+#ifdef U61_DEBUG
   if (debug_file!=NULL)
     {
       fprintf(debug_file," ;message;%25s;%-5d;%s\n","unknown",0,text);
@@ -650,7 +711,7 @@ void U61_Platform::log_to_message_file(char *text)
  */
 void U61_Platform::log_to_debug_file(char *text,char *file,int line)
 {
-#ifdef DEBUG
+#ifdef U61_DEBUG
   if (debug_file!=NULL)
     {
       fprintf(debug_file," ;debug  ;%25s;%-5d;%s\n",file,line,text);
@@ -658,3 +719,4 @@ void U61_Platform::log_to_debug_file(char *text,char *file,int line)
 #endif
 }
 
+#endif //U61_MSVC
