@@ -102,6 +102,7 @@ U61_Player::~U61_Player()
 void U61_Player::reset()
 {
   available=false;
+  history_done=true;
 
   if (source!=NULL)
     {
@@ -173,9 +174,9 @@ U61_Block U61_Player::get_next_block()
 /*
  * returns the number of persistent curses activated
  */
-int U61_Player::get_nb_curse()
+int U61_Player::get_nb_curse(bool good)
 {
-  return last.get_nb_curse();
+  return last.get_nb_curse(good);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -202,7 +203,20 @@ char *U61_Player::get_curse_name()
  */
 int U61_Player::get_background()
 {
-  return last.get_background();
+  int bg=-1;
+
+  /*
+   * When the player is not active we return -1, for the background
+   * does not have to be drawn, and this way we can notice the layout
+   * manager that the background has changed, ie the background image
+   * has to be redrawn.
+   */
+  if (last.is_active())
+    {
+      bg=last.get_background();
+    }
+
+  return bg;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -260,7 +274,7 @@ void U61_Player::init_network(U61_Dispatcher *d,
 
   reset();
 
-  local=false;
+  local=false;;
 
   set_id(id);
   sure.init(id,
@@ -337,6 +351,15 @@ void U61_Player::pump_events()
 	case U61_EVENT_KILL:
 	  kill_needed=true;
 	  break;
+        case U61_EVENT_LOOSE:
+	  register_score();
+	  break;
+        case U61_EVENT_HISTORY_BEGIN:
+	  history_done=false;
+	  break;
+        case U61_EVENT_HISTORY_END:
+	  history_done=true;
+	  break;
 	}
     }
 
@@ -367,10 +390,6 @@ void U61_Player::handle_event(U61_Event *evt)
 {
   if (sure.is_active())
     {
-      if (evt->code==U61_EVENT_LOOSE)
-	{
-	  register_score();
-	}
       if (evt->code==U61_EVENT_START_STOP)
 	{
 	  stop();
@@ -429,13 +448,15 @@ void U61_Player::kill()
 
 /*--------------------------------------------------------------------------*/
 /*
- * draws the map & infos of the player
+ * draws the map of the player
  */
 void U61_Player::draw(int x,int y,int size)
 {
-  last.anticipate(U61_Time::for_event());
-  //last.draw(10,10);
-  last.draw(x,y,size,*anticipation);
+  if (history_done)
+    {
+      last.anticipate(U61_Time::for_event());
+      last.draw(x,y,size,*anticipation);
+    }
 }
 
 /*--------------------------------------------------------------------------*/
