@@ -86,7 +86,7 @@ class U61_Player
   int get_target_id();
   int get_score();
   U61_Block get_next_block();
-  int get_nb_curse();
+  int get_nb_curse(bool good);
   int get_nb_antidote();
   char *get_curse_name();
   int get_background();
@@ -115,6 +115,8 @@ class U61_Player
   bool available;
   bool local;
 
+  bool history_done;
+
   U61_EventSource *source;
   U61_EventCopy *copy;
 
