@@ -57,7 +57,7 @@ class U61_PlayerConfig
 
   bool activable;
 
-  char name[U61_STRING_SIZE];
+  char name[U61_CONST_STRING_SIZE];
 
   bool anticipation;
 
