@@ -68,7 +68,7 @@ U61_Protocol::U61_Protocol(int p,int c)
 {
   port=p;
   channel=c;
-  game=NULL;
+  session=NULL;
   reset();
 }
 
@@ -78,10 +78,10 @@ U61_Protocol::U61_Protocol(int p,int c)
  */
 U61_Protocol::~U61_Protocol()
 {
-  if (game!=NULL)
+  if (session!=NULL)
     {
-      delete game; 
-      game=NULL;
+      delete session; 
+      session=NULL;
     }
 }
 
