@@ -48,6 +48,7 @@
  ---------------------------------------------------------------------------*/
 
 #include <ClanLib/core.h>
+#include <ClanLib/network.h>
 
 #include "connection.h"
 
@@ -99,7 +100,7 @@ class U61_Protocol
   int channel;
   std::string diagnostic;
 
-  CL_NetGame *game;
+  CL_NetSession *session;
 
   int send_id(U61_Connection *conn);
   int recv_id(U61_Connection *conn);
