@@ -105,6 +105,8 @@ bool U61_SaveScriptMenu::save()
   char buffer[U61_CONST_STRING_SIZE];
   FILE *f;
   
+  U61_Global::data.chdir_to_initial_dir();
+  
   strncpy(buffer,U61_Global::remote_script.name_buffer,sizeof(buffer)-1);
   U61_Platform::unstrip_remote_script_path(buffer);
   U61_LOG_DEBUG("Trying to save script to "<<buffer);
@@ -119,6 +121,8 @@ bool U61_SaveScriptMenu::save()
       fclose(f);
       ok=true;
     }
+  
+  U61_Global::data.chdir_to_data_dir();
 
   return ok;
 }
