@@ -95,12 +95,11 @@ void U61_Score::register_game(char *name, bool loc,
   U61_LOG_DEBUG("registering "<<name<<" in score table");
 
   found=false;
-  score/=U61_SCORE_SCORE_DIVIDER;
   time/=U61_TIME_ONE_SECOND;
 
   if (loc)
     {
-      local_str="Local";
+      local_str="Local player";
       local_chr="l";
       size=local.size();
       for (i=0;i<size && !found;++i)
@@ -120,7 +119,7 @@ void U61_Score::register_game(char *name, bool loc,
     }
   else
     {
-      local_str="Remote";
+      local_str="Remote player";
       local_chr="r";
       size=remote.size();
       for (i=0;i<size && !found;++i)
