@@ -52,6 +52,7 @@
 #include "const.h"
 #include "utils.h"
 #include "debug.h"
+#include "global.h"
 
 /*---------------------------------------------------------------------------
  constants
@@ -66,14 +67,16 @@
 #define U61_SCRIPT_LUA_MOVE_DOWN "user_move_down"
 #define U61_SCRIPT_LUA_LAND "user_land"
 #define U61_SCRIPT_LUA_MATCH_PATTERN "user_match_pattern"
-#define U61_SCRIPT_LUA_TIME_CALLBACK "user_time_callback"
+#define U61_SCRIPT_LUA_TIME_CALLBACK_1 "user_time_callback_1"
+#define U61_SCRIPT_LUA_TIME_CALLBACK_10 "user_time_callback_10"
+#define U61_SCRIPT_LUA_TIME_CALLBACK_100 "user_time_callback_100"
 #define U61_SCRIPT_LUA_SQUARE_BLOWN_UP "user_square_blown_up"
 #define U61_SCRIPT_LUA_NEW_CURSE "user_new_curse"
 #define U61_SCRIPT_LUA_DO_CURSE "user_do_curse"
 #define U61_SCRIPT_LUA_USE_ANTIDOTE "user_use_antidote"
 #define U61_SCRIPT_LUA_GET_CURSE_NAME "user_get_curse_name"
 
-#define U61_SCRIPT_C_RESET_BLOCK "u61_reset_block"
+#define U61_SCRIPT_C_CLEAR_BLOCK "u61_clear_block"
 #define U61_SCRIPT_C_CENTER_BLOCK "u61_center_block"
 #define U61_SCRIPT_C_GET_BLOCK_X "u61_get_block_x"
 #define U61_SCRIPT_C_GET_BLOCK_Y "u61_get_block_y"
@@ -186,6 +189,8 @@ bool U61_Script::do_file(char *name)
 {
   bool bSuccess;
   int iResult;
+  
+  U61_Global::data.chdir_to_initial_dir();
 
   bSuccess=false;
 
@@ -201,6 +206,8 @@ bool U61_Script::do_file(char *name)
       U61_LOG_WARNING("Lua error reading script, code is "<<iResult<<".");
       break;
     }
+  
+  U61_Global::data.chdir_to_data_dir();
 
   return bSuccess;
 }
@@ -600,7 +607,7 @@ bool U61_Script::match_pattern(U61_Map *m)
  * it is called about 10 times/sec, and the rate does not increase
  * with the global speed of the game
  */
-void U61_Script::time_callback(U61_Map *m,U61_Block *b)
+void U61_Script::time_callback_1(U61_Map *m,U61_Block *b)
 {
   CL_LuaObject func;
   char command[U61_CONST_STRING_SIZE];
@@ -618,7 +625,73 @@ void U61_Script::time_callback(U61_Map *m,U61_Block *b)
   //lua_callfunction(func);
 
   sprintf(arguments,"()");
-  strcpy(command,U61_SCRIPT_LUA_TIME_CALLBACK);
+  strcpy(command,U61_SCRIPT_LUA_TIME_CALLBACK_1);
+  strcat(command,arguments);
+  lua_beginblock();
+  CL_Lua::dostring(command);
+  lua_endblock();
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * function called on a regular time basis
+ * it can update or modify anything in the map or the block
+ * usefull to implement some curses, and/or update the score
+ * it is called about 10 times/sec, and the rate does not increase
+ * with the global speed of the game
+ */
+void U61_Script::time_callback_10(U61_Map *m,U61_Block *b)
+{
+  CL_LuaObject func;
+  char command[U61_CONST_STRING_SIZE];
+  char arguments[U61_CONST_STRING_SIZE];
+
+  secure_pointers();
+  current_map=m;
+  current_block=b;
+  map_read=true;
+  map_write=true;
+  block_read=true;
+  block_write=true;
+
+  //func=CL_Lua::getglobal(U61_SCRIPT_LUA_NEW_BLOCK);
+  //lua_callfunction(func);
+
+  sprintf(arguments,"()");
+  strcpy(command,U61_SCRIPT_LUA_TIME_CALLBACK_10);
+  strcat(command,arguments);
+  lua_beginblock();
+  CL_Lua::dostring(command);
+  lua_endblock();
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * function called on a regular time basis
+ * it can update or modify anything in the map or the block
+ * usefull to implement some curses, and/or update the score
+ * it is called about 10 times/sec, and the rate does not increase
+ * with the global speed of the game
+ */
+void U61_Script::time_callback_100(U61_Map *m,U61_Block *b)
+{
+  CL_LuaObject func;
+  char command[U61_CONST_STRING_SIZE];
+  char arguments[U61_CONST_STRING_SIZE];
+
+  secure_pointers();
+  current_map=m;
+  current_block=b;
+  map_read=true;
+  map_write=true;
+  block_read=true;
+  block_write=true;
+
+  //func=CL_Lua::getglobal(U61_SCRIPT_LUA_NEW_BLOCK);
+  //lua_callfunction(func);
+
+  sprintf(arguments,"()");
+  strcpy(command,U61_SCRIPT_LUA_TIME_CALLBACK_100);
   strcat(command,arguments);
   lua_beginblock();
   CL_Lua::dostring(command);
@@ -829,13 +902,13 @@ static void return_lua_int(int ret)
 /*--------------------------------------------------------------------------*/
 /*
  * this function is accessible from lua script 
- * it completely resets a block, ie after it the block has no squares left...
+ * it completely clears a block, ie after it the block has no squares left...
  */
-static void reset_block()
+static void clear_block()
 {
   if (current_block!=NULL && block_write)
     {
-      current_block->reset();
+      current_block->clear();
     }
 }
 
@@ -1260,7 +1333,7 @@ static void set_preview_state()
 
   if (current_map!=NULL && map_write)
     {
-       state=(((float) CL_Lua::getparam(1))!=0.);
+      state=(((float) CL_Lua::getparam(1))!=0.);
 
       current_map->set_preview_state(state);
     }
@@ -1450,13 +1523,15 @@ static void register_curse()
 {
   int i;
   int length;
+  bool good;
 
   if (current_map!=NULL && map_write)
     {
       i=CL_Lua::getparam(1);
       length=CL_Lua::getparam(2);
+      good=(((float) CL_Lua::getparam(3))!=0.);
 
-      current_map->register_curse(i,length);
+      current_map->register_curse(i,length,good);
     }
 }
 
@@ -1484,9 +1559,13 @@ static void cancel_curse()
  */
 static void get_oldest_curse()
 {
+  bool good;
+
   if (current_map!=NULL && map_read)
     {
-      return_lua_int(current_map->get_oldest_curse());
+      good=(((float) CL_Lua::getparam(1))!=0.);
+
+      return_lua_int(current_map->get_oldest_curse(good));
     }
 }
 
@@ -1497,9 +1576,13 @@ static void get_oldest_curse()
  */
 static void get_nb_curses()
 {
+  bool good;
+
   if (current_map!=NULL && map_read)
     {
-      return_lua_int(current_map->get_nb_curse());
+      good=(((float) CL_Lua::getparam(1))!=0.);
+
+      return_lua_int(current_map->get_nb_curse(good));
     }
 }
 
@@ -1561,7 +1644,7 @@ static void is_block_ok()
  */
 void U61_Script::record_all()
 {
-  CL_Lua::record(U61_SCRIPT_C_RESET_BLOCK,reset_block);
+  CL_Lua::record(U61_SCRIPT_C_CLEAR_BLOCK,clear_block);
   CL_Lua::record(U61_SCRIPT_C_CENTER_BLOCK,center_block);
   CL_Lua::record(U61_SCRIPT_C_GET_BLOCK_X,get_block_x);
   CL_Lua::record(U61_SCRIPT_C_GET_BLOCK_Y,get_block_y);
