@@ -101,10 +101,10 @@ U61_ServerProtocol::~U61_ServerProtocol()
 	}
     }
     
-  if (game!=NULL)
+  if (session!=NULL)
     {
-      delete game;
-      game=NULL;
+      delete session;
+      session=NULL;
     }
 }
 
@@ -117,15 +117,16 @@ void U61_ServerProtocol::check_connection()
 {
   int i;
   U61_Player *p;
-  CL_NetComputer *client;
+  CL_NetComputer client;
   U61_Event evt;  
 
-  if (game!=NULL && (client=game->receive_computer_leave())!=NULL)
+  if (session!=NULL)
     {
+      client=(CL_NetComputer) session->receive_computer_leave();
       for (i=0;i<U61_GAME_NB_NET_GROUPS-1;++i)
 	{
 	  if (connection[i]!=NULL
-	      && connection[i]->is_associated(client))
+	      && connection[i]->is_associated(&client))
 	    {
 	      if (dispatcher!=NULL)
 		{
@@ -325,16 +326,16 @@ int U61_ServerProtocol::start_listening()
 
   try 
     {
-      game=CL_Network::create_game(U61_PROTOCOL_GAME_ID,port);
+      session=new CL_NetSession(U61_PROTOCOL_GAME_ID,port);
     }
   catch (CL_Error e)
     {
       result=U61_PROTOCOL_FAILED;
       diagnostic+=e.message;
-      game=NULL;
+      session=NULL;
     }
 
-  if (game!=NULL)
+  if (session!=NULL)
     {
       result=U61_PROTOCOL_DONE;
     };
@@ -351,28 +352,39 @@ int U61_ServerProtocol::start_listening()
 int U61_ServerProtocol::accept_client()
 {
   int result=U61_PROTOCOL_LATER;
-  const CL_NetComputer *computer;
+  CL_NetComputer computer;
   
-  if ((computer=game->receive_computer_join())!=NULL)
+  try 
     {
-      if ((new_connection=get_free_connection())<0)
+      if (!((computer=(CL_NetComputer) 
+	     session->receive_computer_join())==
+	    CL_NetComputer(NULL)))
 	{
-	  result=U61_PROTOCOL_FAILED;
-	}
-      else
-	{  
-	  /*
-	   * There's a connection available to talk with the client
-	   * so we can discuss with him.
-	   * It should be important to check when the computer
-	   * object is deleted by the way...
-	   */
-	  connection[new_connection]=new 
-	    U61_Connection(game,(CL_NetComputer *) computer,
-			   channel+new_connection,true);        
-	  result=U61_PROTOCOL_DONE;
+	  if ((new_connection=get_free_connection())<0)
+	    {
+	      result=U61_PROTOCOL_FAILED;
+	    }
+	  else
+	    {  
+	      /*
+	       * There's a connection available to talk with the client
+	       * so we can discuss with him.
+	       * It should be important to check when the computer
+	       * object is deleted by the way...
+	       */
+	      connection[new_connection]=new 
+		U61_Connection(session,computer,
+			       channel+new_connection,true);        
+	      result=U61_PROTOCOL_DONE;
+	    }
 	}
     }
+  catch (CL_Error e)
+    {
+      /*
+       * Here we trap any error raised by receive_computer_join
+       */
+    }
   
   return result;
 }
@@ -585,10 +597,10 @@ void U61_ServerProtocol::handle_error(int result)
 	  connection[new_connection]=NULL;
 	}
 
-      if (game==NULL)
+      if (session==NULL)
 	{
 	  /*
-	   * game is NULL, this means we have not successfully passed
+	   * session is NULL, this means we have not successfully passed
            * the opening of the listening socket.
            * so we restart everything from scratch
            */    
@@ -597,7 +609,7 @@ void U61_ServerProtocol::handle_error(int result)
       else
 	{
 	  /*
-	   * game is not NULL, this means the protocol failed somewhere
+	   * session is not NULL, this means the protocol failed somewhere
 	   * on an opened socket, therefore we go back to LISTENING mode
 	   * ie accept new connection on the listening socket
 	   */
