@@ -63,9 +63,9 @@ U61_SoundMenu::U61_SoundMenu(U61_Menu *parent,
 {
   config=conf;
   add_item(new U61_Number("Sound fx volume",
-			  &(conf->sound_volume),0,U61_Sound::VOLUME_MAX));
+			  &(conf->sound_volume),0,U61_SOUND_VOLUME_MAX));
   add_item(new U61_Number("Music volume",
-			  &(conf->music_volume),0,U61_Music::VOLUME_MAX));
+			  &(conf->music_volume),0,U61_MUSIC_VOLUME_MAX));
   select(0);
 }
 
