@@ -47,6 +47,7 @@
 #include "networkmenu.h"
 #include "global.h"
 #include "activeplayermenu.h"
+#include "scoremenu.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -85,15 +86,21 @@ U61_Menu *U61_StartMenu::validate()
   switch (selection)
     {
     case 0:
-      next_menu=new U61_PausingMenu(new U61_AloneMenu(this));
+      next_menu=new U61_PausingMenu
+	(new U61_AloneMenu
+	 (new U61_ScoreMenu(this)));
       U61_Global::game.start_local_alone();
       break;
     case 1:
-      next_menu=new U61_PausingMenu(new U61_MultiplayerMenu(this));
+      next_menu=new U61_PausingMenu
+	(new U61_MultiplayerMenu
+	 (new U61_ScoreMenu(this)));
       U61_Global::game.start_local_multiplayer();
       break;
     case 2:
-      next_menu=new U61_NonPausingMenu(new U61_NetworkMenu(this));
+      next_menu=new U61_NonPausingMenu
+	(new U61_NetworkMenu
+	 (new U61_ScoreMenu(this)));
       U61_Global::game.start_network_new();
       break;
     case 3:
