@@ -44,6 +44,12 @@
 
 #include <ClanLib/core.h>
 
+/*---------------------------------------------------------------------------
+ constants
+ ---------------------------------------------------------------------------*/
+
+#define U61_TIME_ONE_SECOND 100
+
 /*---------------------------------------------------------------------------
  classes
  ---------------------------------------------------------------------------*/
@@ -67,7 +73,6 @@ public:
     static bool is_paused();   
     static void idle();
     
-    static const int ONE_SECOND=100;
 protected:
     static int reset_offset;
     static int alter_offset;
@@ -78,10 +83,11 @@ protected:
     static unsigned int last_for_logic;    
     static unsigned int last_for_display;
 
-    static const int TIME_UNIT=10;
-    static const int IDLE_DELAY=5;
-
     static int system_time();
 };
 
 #endif
+
+
+
+
