@@ -43,6 +43,12 @@
 
 #include <ClanLib/core.h>
 
+/*---------------------------------------------------------------------------
+ constants
+ ---------------------------------------------------------------------------*/
+
+#define U61_UTILS_RANDOM_DEFAULT        10000
+
 /*---------------------------------------------------------------------------
  classes
  ---------------------------------------------------------------------------*/
@@ -50,9 +56,8 @@
 class U61_Utils
 {
 public:
-    static const int RANDOM_DEFAULT=10000;
+    static int random(int scale);
 
-    static int random(int scale=RANDOM_DEFAULT);
     static bool set_videomode(int w,int h,bool fullscreen);
 protected:
 };
